!  ASIS method 0D Fortran code demonstrator
!
!  Reference:
!    ASIS v1.0: an adaptive solver for the simulation of atmospheric chemistry
!    Daniel Cariolle, Philippe Moinat, Hubert Teyssèdre, Luc Giraud, Béatrice Josse, and Franck Lefèvre
!    Geosci. Model Dev. Discuss., doi:10.5194/gmd-2016-281, 2016
!    Manuscript accepted for publication in the journal Geosci. Model Dev.
!    Published: 21 November 2016
!
!
!  MAIN PROGRAM
!    refer to section 2.2 of the paper and Eq. 7
!
PROGRAM ASIS_0D
!
USE TYPES, ONLY : JPIM,JPRB

USE case_module, ONLY : case_name,IU_OUT,SEMI,EMISTEP, &
                     &  dtt,ndays,ndt_day, &
                     &  tauless,PHNM, &
                     &  SOLMET

USE solution_module, ONLY : MM,MAT,tmp,tmp1,tmp2,TL,TP, &
                         &  nsolve, niterm, &
                         &  dealloc_asis, dealloc_meth

USE chemistry_module, ONLY : CONC,EMIRATE,NB_SP,C_ST, &
                          &  dealloc_c, dealloc_z, dealloc_v, dealloc_out

USE photodis_module, ONLY : dealloc_J

USE num_species_module, ONLY : JPHNO3

USE M_define_dt, ONLY : define_dt
USE M_fill_asis, ONLY : fill_matrix
USE M_storeC, ONLY : storec

IMPLICIT NONE

REAL(KIND=JPRB) :: dt1,dtg,dt           ! Time steps
REAL(KIND=JPRB) :: ctime                ! current time
INTEGER(KIND=JPIM) :: flag              ! set greater than 1 when time step completed

REAL(KIND=JPRB) :: cdt                  ! time covered within a time step

INTEGER(KIND=JPIM) :: ki                ! time step number

INTEGER(KIND=JPIM) :: nit               ! number of sub steps
INTEGER(KIND=JPIM) :: nitm              ! mean number of sub steps

INTEGER(KIND=JPIM) :: id,kq,n           ! Loop indices

REAL(KIND=JPRB) :: dtmax




! DEFINITIONS AND INITIALIZATIONS
!-----------------
CALL INIT



! TIME INTEGRATION
!-----------------
ki=0            ! time step number
nitm=0
ctime=0.        ! current time since time 0 of integration

!------------------------------------------------ START TIME INTEGRATION
do id=1,ndays           !-- day loop
do kq=1,ndt_day         !-- time step loop, new time step of length dtt

  cdt=0.0_JPRB          ! time since beginning of time step

  ! Calculate reaction rates
  CALL reaction_rates(kq)

  ! Apply emissions if EMISTEP, otherwise applied at each substep 
  if (EMISTEP) then 
     CONC=CONC+EMIRATE*dtt
  endif           

  ! Rain scavenging applied to HNO3
  CONC(JPHNO3)=(CONC(JPHNO3)+2.0e-9_JPRB*PHNM*dtt/tauless) &
                  /(1.0_JPRB+dtt/tauless);


  ! CALL HETERO   - introduce here heterogeneous chemistry


  ! ctime = current time since time 0. of integration
  ! dtt = time step, split in sub time steps of adaptative size
  ! CONC = concentration updated at the end of each sub time step
  !
  ! dt1 = tn - tn-1		previous sub time step
  ! dtg = tn+1 - tn		next sub time step / guess
  ! dt = tn+1 - tn		next sub time step / chosen

  ! tmp2 = Cn-1		concentration at the previous time
  ! tmp = Cn			concentration at the current time
  ! tmp1 = Cn+1		concentration at the next time

  ! cdt = current time since beginning of dtt time step

  dt=dtt
  dt1=dt
  tmp2=CONC


  nit=0         ! count the number of sub-steps

  ! ## SUB STEP LOOP ##
  ! split time step dtt into several sub time steps of varying length dt
  flag=0
  do while ( flag < 1 )


    ! ....... Calculate Jacobian  (MM = -M  in Eq 7 of ASIS paper)
    CALL fill_matrix(CONC,MM, &
                     SEMI,TL,TP )

    
    ! ....... Adaptative evaluation of the sub time step
    dtg=dt      ! first guess
    dt1=dt      ! previous sub time step
    tmp = CONC

    dtmax=dtt-cdt
    CALL define_dt(dtg,dt1,dtmax,  &
   &               tmp2,tmp,  &
   &               MM,  &
   &               TL,TP )
    if ( (dtt-(cdt+dtg)) < 1.e-8*dtt ) dtg=dtt-cdt ! round up

    dt=dtg      ! new sub time step

 
    ! ....... Calculate concentration at the end of the sub step
    ! ....... solve the system   (I+dt*MM) Cn+1 = Cn + F dt
       ! Form the matrix I+dt*MM
       MAT=dt*MM
       do n=1,NB_SP
          MAT(n,n)=1.0_JPRB + MAT(n,n)
       enddo

       ! RHS of the system and solution guess (when needed by the method)
       if (EMISTEP) then
          tmp1=tmp              ! RHS

          if ( SOLMET /= 'DGESV' ) then ! Solution Guess needed for all methods except the direct one
             if (SEMI) then
                tmp2=(tmp+TP*dt)/(1+TL*dt)    ! improved guess if TL and TP available
             else
                tmp2=tmp                      ! basis guess
             endif
          endif

       else
          ! Apply emissions before solving the linear system
          tmp1=tmp+EMIRATE*dt   ! RHS

          if ( SOLMET /= 'DGESV' ) then ! Solution Guess needed for all methods except the direct one
             if (SEMI) then
                tmp2=(tmp+(TP+EMIRATE)*dt)/(1+TL*dt)
             else
                tmp2=tmp
             endif
          endif

       endif

       CALL SOLVESYS(MAT,tmp1,tmp2)  ! M=matrix, tmp1=RHS/Solution, tmp2=Solution Guess



    cdt=cdt+dt      ! increment current time (reference = beginning of time step)
    ctime=ctime+dt  ! increment current time (reference = beginning of integration)

    !do n=1,NB_SP
    !    if (tmp1(n).lt.0._JPRB) write(*,*) '** Warning ** Negative value for specie number ',n
    !enddo

    CONC=tmp1
    tmp2=tmp

    nit=nit+1       ! increment the count of the number of sub steps

 
    if ( cdt >= dtt ) flag=2	! time step dtt completed
 
  enddo ! continue with next sub step if flag < 1

  ! ## SUB STEP LOOP ## END


  ! store for output and post-processing
  ki=ki+1
  C_ST(ki,:)=CONC
  nitm=nitm+nit

enddo	! 1/4 of hour
enddo	! day



if (ki.ne.ndays*ndt_day) then
   write(*,*) '****** WARNING *******'
   write(*,*) 'ki = ',ki,' did not reach the expected number of time steps, ',ndays*ndt_day
   write(*,*)
endif

nitm=nitm/ki
write(*,*) ' ----- Mean number of sub time steps',nitm
write(*,*) '  --> mean sub time step value =',dtt/nitm

if (nsolve.gt.0 .and. SOLMET /= 'DGESV') then
  write(*,*) 
  write(*,*)  ' ---- ITERATIVE METHOD -- Mean Number of iterations', niterm/nsolve
endif




! write output to files
call STOREC(C_ST,PHNM,ndays*ndt_day,dtt,IU_OUT,case_name)




! finalize : deallocate arrays
!    - chemistry
call dealloc_c
call dealloc_J
call dealloc_z
call dealloc_v
call dealloc_out
!    - solution method
call dealloc_asis
call dealloc_meth

END PROGRAM ASIS_0D
