!  ASIS method 0D Fortran code demonstrator
!
!  Reference:
!    ASIS v1.0: an adaptative solver for the simulation of atmospheric chemistry
!    Daniel Cariolle, Philippe Moinat, Hubert Teyssèdre, Luc Giraud, Béatrice Josse, and Franck Lefèvre
!    Geosci. Model Dev. Discuss., doi:10.5194/gmd-2016-281, 2016
!    Manuscript accepted for publication in the journal Geosci. Model Dev.
!    Published: 21 November 2016
!
!  ADAPTATIVE TIME STEP
!     Iterative evaluation of the appropriate time step dtnew based on the local error indicator E
!     and the absolute and relative error tolerance ATOL and RTOL
!     (section 2.3 of the paper)
!
MODULE M_define_dt

CONTAINS

SUBROUTINE define_dt(dtnew,dtold,dtmax,  &
   &                 Cold,Ccur,  &
   &                 MM,  &
   &                 TL,TP)


USE TYPES,            ONLY : JPIM,JPRB
USE case_module,      ONLY : EMISTEP,SEMI, &
   &                        nitmax,dtmin,ATOL,RTOL,coefmin,coefmax
USE chemistry_module, ONLY : NB_SP, &
                             EMIRATE

IMPLICIT NONE

! Argument variables
REAL(KIND=JPRB) :: dtnew,dtold,dtmax
REAL(KIND=JPRB), DIMENSION(NB_SP) :: Cold,Ccur
REAL(KIND=JPRB), DIMENSION(NB_SP,NB_SP) :: MM
REAL(KIND=JPRB), DIMENSION(*) :: TL,TP

! Local variables
INTEGER(KIND=JPIM) :: kit,n
REAL(KIND=JPRB) :: gamma,E,coef,W
REAL(KIND=JPRB), DIMENSION(NB_SP) :: Cnew
REAL(KIND=JPRB), DIMENSION(NB_SP,NB_SP) :: MAT

    do kit=1,nitmax

     if (SEMI) then   ! use one iteration of SIS semi-implicit integration
                      ! to obtain the test solution used to determine the time step
       if (EMISTEP) then ! emission applied at the beginning of the time step
          do n=1,NB_SP
            Cnew(n)=(Ccur(n)+TP(n)*dtnew)/(1.0_JPRB+TL(n)*dtnew)
          enddo
       else              ! emission applied at each sub time step
          do n=1,NB_SP
            Cnew(n)=(Ccur(n)+(TP(n)+EMIRATE(n))*dtnew)/(1.0_JPRB+TL(n)*dtnew)
          enddo
       endif

     else             ! calculate accurately the test solution 
                      ! used to determine the time step
       ! Form the matrix I+dtnew*MM
       MAT=dtnew*MM
       do n=1,NB_SP
          MAT(n,n)=1.0_JPRB + MAT(n,n)
       enddo

       ! Form the RHS of the system 
       if (EMISTEP) then ! emission applied at the beginning of the time step
          Cnew=Ccur
       else              ! emission applied at each sub time step
          Cnew=Ccur+EMIRATE*dtnew
       endif

       ! solve the linear system  M*Cn+1=Cn (RHS in Cnew, then replaced by solution)
       call SOLVESYS(MAT,Cnew,Ccur)
     endif

     gamma=dtold/dtnew

     E=0.0_JPRB

     do n=1,NB_SP
!!!        W = RTOL*max(ATOL,Ccur(n))
        W = ATOL+RTOL*Ccur(n)
        E = max(E , abs( 2.0_JPRB*curvat(gamma,Cnew(n),Ccur(n),Cold(n))/ W ) ) ! Eq 10 of paper
     enddo

     coef=max(coefmin, min(coefmax,0.8_JPRB/sqrt(E)))         ! Eq 12 of paper, time step coefficient
     dtnew=max(dtmin,dtnew*coef)
     dtnew=min(dtmax,dtnew)
 
    enddo		! end iterations

END SUBROUTINE DEFINE_DT


REAL(KIND=JPRB) FUNCTION curvat(r,CP1,C,CM1)
USE TYPES, ONLY : JPIM,JPRB
IMPLICIT NONE
REAL(KIND=JPRB) :: r,CP1,C,CM1
curvat=(r*CP1 - (1.0_JPRB+r)*C + CM1)/(1.0_JPRB+r);
END FUNCTION curvat

END MODULE M_define_dt
