!  ASIS method 0D Fortran code demonstrator
!
!  Reference:
!    ASIS v1.0: an adaptative solver for the simulation of atmospheric chemistry
!    Daniel Cariolle, Philippe Moinat, Hubert Teyssèdre, Luc Giraud, Béatrice Josse, and Franck Lefèvre
!    Geosci. Model Dev. Discuss., doi:10.5194/gmd-2016-281, 2016
!    Manuscript accepted for publication in the journal Geosci. Model Dev.
!    Published: 21 November 2016
!
!  LINEAR SYSTEM VARIABLES
!    matrix, arrays and solution method variables
!
MODULE solution_module

USE TYPES, ONLY : JPIM,JPRB
USE case_module, ONLY : SEMI, &
                     &  SOLMET,itersol,cvsol, &
                     &  ipl_gmres,ios_gmres,irt_gmres,irl_gmres
USE chemistry_module, ONLY : NB_SP

IMPLICIT NONE

! Basic arrays
REAL(KIND=JPRB), DIMENSION(:,:), ALLOCATABLE, SAVE :: MM,MAT		! ASIS system Matrices 
REAL(KIND=JPRB), DIMENSION(:), ALLOCATABLE, SAVE :: tmp,tmp1,tmp2	! work arrays, solution or RHS of the system

REAL(KIND=JPRB), DIMENSION(:), ALLOCATABLE, SAVE :: TL,TP		! loss and production (SEMI)


! Additional arrays specific to each solution method

! DGESV
INTEGER(KIND=JPIM), DIMENSION(:), ALLOCATABLE :: IPIV		! Pivot indices



! Counters
INTEGER(KIND=JPIM) :: nsolve	! nb of calls to SOLVESYS
INTEGER(KIND=JPIM) :: niterm	! nb of iterations for an iterative method
 

! GMRES
INTEGER(KIND=JPIM) :: lwork,mrestart,icntl(8), infog(3)
REAL (KIND=JPRB) :: cntl(5), rinfog(2)


CONTAINS


SUBROUTINE alloc_asis 
ALLOCATE(MM(NB_SP,NB_SP)) 	! ASIS system Matrices 
MM=0._JPRB
ALLOCATE(MAT(NB_SP,NB_SP))
MAT=0._JPRB
ALLOCATE(tmp(NB_SP))
tmp=0._JPRB
ALLOCATE(tmp1(NB_SP))
tmp1=0._JPRB
ALLOCATE(tmp2(NB_SP))
tmp2=0._JPRB

if (SEMI) then
  ALLOCATE(TL(NB_SP))
  ALLOCATE(TP(NB_SP))
else
  ALLOCATE(TL(1))
  ALLOCATE(TP(1))
endif
TL=0._JPRB
TP=0._JPRB

END SUBROUTINE alloc_asis

SUBROUTINE dealloc_asis 
DEALLOCATE(MM)
DEALLOCATE(MAT)
DEALLOCATE(tmp)
DEALLOCATE(tmp1)
DEALLOCATE(tmp2)
DEALLOCATE(TL)
DEALLOCATE(TP)
END SUBROUTINE dealloc_asis


SUBROUTINE alloc_meth 
 if ( SOLMET == 'DGESV' ) then
    ALLOCATE(IPIV(NB_SP))
    IPIV=0
 else
    ALLOCATE(IPIV(1))
 endif
END SUBROUTINE alloc_meth 

SUBROUTINE dealloc_meth 
DEALLOCATE(IPIV)
END SUBROUTINE dealloc_meth 


SUBROUTINE ini_counter 
 nsolve=0
 niterm=0
END SUBROUTINE ini_counter 


SUBROUTINE set_solve

 if ( SOLMET == 'GMRES' ) then
 ! Initialize the control parameters to default value
      call init_dgmres(icntl,cntl)
 ! Tune differently some parameters
      ipl_gmres = 1  ! Preconditioner location	0=NO, 1=LEFT, 2=RIGHT, 3=DBLE SIDE
      ios_gmres = 0  ! Orthogonalization scheme 0=MGS, 1=IMGS, 2=CGS, 3=ICGS
      irt_gmres = 30 ! Restart parameter
      irl_gmres = 1  ! Residual calculation strategy at restart 0=recurrence formula used, 1=explicit

      icntl(1) = 0   ! stdout for error messages -- no output
      icntl(2) = 0   ! stdout for warnings -- no output
      icntl(3) = 0   ! save the convergence history in file fort.XX or do not save if 0
      icntl(4) = ipl_gmres	! preconditioner location, 0=NO, 1=LEFT, 2=RIGHT, 3=DBLE SIDE
      icntl(5) = ios_gmres	! orthogonalization scheme, 0=MGS, 1=IMGS, 2=CGS, 3=ICGS
      icntl(6) = 1   ! initial guess -- User provided
      icntl(7) = itersol	! Maximum number of iterations
      icntl(8) = irl_gmres	! residual calculation strategy at restart, 0=recurrence formula used, 1=explicit

      cntl(1) = cvsol		! Tolerance for convergence, 1.0 d -5 by default
      mrestart = irt_gmres	! restart parameter

      lwork = mrestart*mrestart + mrestart*(NB_SP+5) + 6*NB_SP + mrestart + 1
 endif

END SUBROUTINE set_solve

END MODULE solution_module
