!  ASIS method 0D Fortran code demonstrator
!
!  Reference:
!    ASIS v1.0: an adaptative solver for the simulation of atmospheric chemistry
!    Daniel Cariolle, Philippe Moinat, Hubert Teyssèdre, Luc Giraud, Béatrice Josse, and Franck Lefèvre
!    Geosci. Model Dev. Discuss., doi:10.5194/gmd-2016-281, 2016
!    Manuscript accepted for publication in the journal Geosci. Model Dev.
!    Published: 21 November 2016
!
!  PHOTODISSOCIATION
!    declare variables
!    read tables from file  TUVfile  (name specified in the namelist)
!    fill the J (photodissociation rates) and seq (night/day) arrays
!
MODULE photodis_module

USE TYPES, ONLY : JPIM,JPRB

USE case_module, ONLY : ndt_day, &
   &                    IU_TUV,TUVfile


IMPLICIT NONE

INTEGER(KIND=JPIM), PARAMETER :: nphoTUV=97                 ! Number of photolysis reactions available in the TUVfile 
REAL(KIND=JPRB), DIMENSION(:,:), ALLOCATABLE, SAVE :: J     ! Photodissociation rates
REAL(KIND=JPRB), DIMENSION(:), ALLOCATABLE, SAVE :: seq     ! Night/Day, 0/1 flag
!       time step index:  1 --> 0H00, ndt_day --> time step before 24H00


!  Selection of the photolysis reactions used in the RACMOBUS scheme
!   - the number should correspond to their occurence in the TUV file
!   - make sure the indices are lower than  nphoTUV
INTEGER(KIND=JPIM) :: JJ_O2 =   1 ! O2 -> O + O                                       
INTEGER(KIND=JPIM) :: JJ_O3a =   2 ! O3 -> O2 + O(1D)                                  
INTEGER(KIND=JPIM) :: JJ_O3b =   3 ! O3 -> O2 + O(3P)                                  
INTEGER(KIND=JPIM) :: JJ_H2O2 =   4 ! H2O2 -> 2 OH                                      
INTEGER(KIND=JPIM) :: JJ_NO2 =   5 ! NO2 -> NO + O(3P)                                 
INTEGER(KIND=JPIM) :: JJ_NO3a =   6 ! NO3 -> NO + O2                                    
INTEGER(KIND=JPIM) :: JJ_NO3b =   7 ! NO3 -> NO2 + O(3P)                                
INTEGER(KIND=JPIM) :: JJ_N2O5a =   8 ! N2O5 -> NO3 + NO + O(3P)                          
INTEGER(KIND=JPIM) :: JJ_N2O5b =   9 ! N2O5 -> NO3 + NO2                                 
INTEGER(KIND=JPIM) :: JJ_N2O =  10 ! N2O -> N2 + O(1D)                                 
INTEGER(KIND=JPIM) :: JJ_HONO =  11 ! HNO2 -> OH + NO                                   
INTEGER(KIND=JPIM) :: JJ_HNO3 =  12 ! HNO3 -> OH + NO2                                  
INTEGER(KIND=JPIM) :: JJ_HNO4 =  13 ! HNO4 -> HO2 + NO2                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  14 ! NO3-(aq) -> NO2(aq) + O-                          
!INTEGER(KIND=JPIM) :: JJ_XXX =  15 ! NO3-(aq) -> NO2-(aq) + O(3P)                      
INTEGER(KIND=JPIM) :: JJ_HCHOb =  16 ! CH2O -> H + HCO                                   
INTEGER(KIND=JPIM) :: JJ_HCHOa =  17 ! CH2O -> H2 + CO                                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  18 ! CH3CHO -> CH3 + HCO                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  19 ! CH3CHO -> CH4 + CO                                
!INTEGER(KIND=JPIM) :: JJ_XXX =  20 ! CH3CHO -> CH3CO + H                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  21 ! C2H5CHO -> C2H5 + HCO                             
!INTEGER(KIND=JPIM) :: JJ_XXX =  22 ! CH2(OH)CHO -> Products                            
!INTEGER(KIND=JPIM) :: JJ_XXX =  23 ! CH2=CHCHO -> Products                             
!INTEGER(KIND=JPIM) :: JJ_XXX =  24 ! CH2=C(CH3)CHO -> Products                         
!INTEGER(KIND=JPIM) :: JJ_XXX =  25 ! CH3COCH3 -> CH3CO + CH3                           
!INTEGER(KIND=JPIM) :: JJ_XXX =  26 ! CH3COCHCH2 -> Products                            
!INTEGER(KIND=JPIM) :: JJ_XXX =  27 ! CH3COCH2CH3 -> CH3CO + CH2CH3                     
!INTEGER(KIND=JPIM) :: JJ_XXX =  28 ! CH2(OH)COCH3 -> CH3CO + CH2(OH)                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  29 ! CH2(OH)COCH3 -> CH2(OH)CO + CH3                   
INTEGER(KIND=JPIM) :: JJ_OP1 =  30 ! CH3OOH -> CH3O + OH                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  31 ! HOCH2OOH -> HOCH2O. + OH                          
!INTEGER(KIND=JPIM) :: JJ_XXX =  32 ! CH3CO(OOH) -> Products                            
!INTEGER(KIND=JPIM) :: JJ_XXX =  33 ! CH3ONO2 -> CH3O + NO2                             
!INTEGER(KIND=JPIM) :: JJ_XXX =  34 ! CH3CH2ONO2 -> CH3CH2O + NO2                       
!INTEGER(KIND=JPIM) :: JJ_XXX =  35 ! CH3CHONO2CH3 -> CH3CHOCH3 + NO2                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  36 ! CH2(OH)CH2(ONO2) -> CH2(OH)CH2(O.) + NO2          
!INTEGER(KIND=JPIM) :: JJ_XXX =  37 ! CH3COCH2(ONO2) -> CH3COCH2(O.) + NO2              
!INTEGER(KIND=JPIM) :: JJ_XXX =  38 ! C(CH3)3(ONO2) -> C(CH3)3(O.) + NO2                
!INTEGER(KIND=JPIM) :: JJ_XXX =  39 ! CH3CO(OONO2) -> CH3CO(OO) + NO2                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  40 ! CH3CO(OONO2) -> CH3CO(O) + NO3                    
!INTEGER(KIND=JPIM) :: JJ_XXX =  41 ! CH3CH2CO(OONO2) -> CH3CH2CO(OO) + NO2             
!INTEGER(KIND=JPIM) :: JJ_XXX =  42 ! CH3CH2CO(OONO2) -> CH3CH2CO(O) + NO3              
!INTEGER(KIND=JPIM) :: JJ_XXX =  43 ! CHOCHO -> HCO + HCO                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  44 ! CHOCHO -> CH2O + CO                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  45 ! CH3COCHO -> CH3CO + HCO                           
!INTEGER(KIND=JPIM) :: JJ_XXX =  46 ! CH3COCOCH3 -> Products                            
!INTEGER(KIND=JPIM) :: JJ_XXX =  47 ! CH3COCO(OH) -> Products                           
INTEGER(KIND=JPIM) :: JJ_Cl2 =  48 ! Cl2 -> Cl + Cl                                    
!INTEGER(KIND=JPIM) :: JJ_XXX =  49 ! ClOOCl -> Cl + ClOO                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  50 ! ClOO -> Products                                  
INTEGER(KIND=JPIM) :: JJ_ClONO2a =  51 ! ClONO2 -> Cl + NO3                                
INTEGER(KIND=JPIM) :: JJ_ClONO2b =  52 ! ClONO2 -> ClO + NO2                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  53 ! Br2 -> Br + Br  
INTEGER(KIND=JPIM) :: JJ_BrO =  54 ! BrO -> Br + O                                     
INTEGER(KIND=JPIM) :: JJ_HOBr =  55 ! HOBr -> OH + Br                                   
INTEGER(KIND=JPIM) :: JJ_BrONO2a =  56 ! BrONO2 -> BrO + NO2                               
INTEGER(KIND=JPIM) :: JJ_BrONO2b =  57 ! BrONO2 -> Br + NO3                                
INTEGER(KIND=JPIM) :: JJ_CH3Cl =  58 ! CH3Cl -> Products                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  59 ! CCl2O -> Products                                 
INTEGER(KIND=JPIM) :: JJ_CCl4 =  60 ! CCl4 -> Products                                  
!INTEGER(KIND=JPIM) :: JJ_XXX =  61 ! CClFO -> Products                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  62 ! CF2O -> Products                                  
INTEGER(KIND=JPIM) :: JJ_CFC113 =  63 ! CF2ClCFCl2 (CFC-113) -> Products                  
!INTEGER(KIND=JPIM) :: JJ_XXX =  64 ! CF2ClCF2Cl (CFC-114) -> Products                  
!INTEGER(KIND=JPIM) :: JJ_XXX =  65 ! CF3CF2Cl (CFC-115) -> Products                    
INTEGER(KIND=JPIM) :: JJ_CFC11 =  66 ! CCl3F (CFC-11) -> Products                        
INTEGER(KIND=JPIM) :: JJ_CFC12 =  67 ! CCl2F2 (CFC-12) -> Products                       
INTEGER(KIND=JPIM) :: JJ_CH3CCl3 =  68 ! CH3CCl3 -> Products                               
!INTEGER(KIND=JPIM) :: JJ_XXX =  69 ! CF3CHCl2 (HCFC-123) -> Products                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  70 ! CF3CHFCl (HCFC-124) -> Products                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  71 ! CH3CFCl2 (HCFC-141b) -> Products                  
!INTEGER(KIND=JPIM) :: JJ_XXX =  72 ! CH3CF2Cl (HCFC-142b) -> Products                  
!INTEGER(KIND=JPIM) :: JJ_XXX =  73 ! CF3CF2CHCl2 (HCFC-225ca) -> Products              
!INTEGER(KIND=JPIM) :: JJ_XXX =  74 ! CF2ClCF2CHFCl (HCFC-225cb) -> Products            
INTEGER(KIND=JPIM) :: JJ_HCFC22 =  75 ! CHClF2 (HCFC-22) -> Products                      
INTEGER(KIND=JPIM) :: JJ_CH3Br =  76 ! CH3Br -> Products                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  77 ! CHBr3 -> Products                                 
INTEGER(KIND=JPIM) :: JJ_H1301 =  78 ! CF3Br (Halon-1301) -> Products                    
!INTEGER(KIND=JPIM) :: JJ_XXX =  79 ! CF2BrCF2Br (Halon-2402) -> Products               
!INTEGER(KIND=JPIM) :: JJ_XXX =  80 ! CF2Br2 (Halon-1202) -> Products                   
INTEGER(KIND=JPIM) :: JJ_H1211 =  81 ! CF2BrCl (Halon-1211) -> Products                  
!INTEGER(KIND=JPIM) :: JJ_XXX =  82 ! (CH3)2NNO -> Products                             
!INTEGER(KIND=JPIM) :: JJ_XXX =  83 ! ClO -> Cl + O(1D)                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  84 ! ClO -> Cl + O(3P)                                 
INTEGER(KIND=JPIM) :: JJ_ClNO2 =  85 ! ClNO2 -> Cl + NO2                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  86 ! BrNO -> Br + NO                                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  87 ! BrNO2 -> Br + NO2                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  88 ! BrONO -> Br + NO2                                 
!INTEGER(KIND=JPIM) :: JJ_XXX =  89 ! BrONO -> BrO + NO                                 
INTEGER(KIND=JPIM) :: JJ_HOCl =  90 ! HOCl -> HO + Cl                                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  91 ! NOCl -> NO + Cl                                   
INTEGER(KIND=JPIM) :: JJ_OClO =  92 ! OClO -> Products                                  
INTEGER(KIND=JPIM) :: JJ_BrCl =  93 ! BrCl -> Br + Cl                                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  94 ! CH3(OONO2) -> CH3(OO) + NO2                       
!INTEGER(KIND=JPIM) :: JJ_XXX =  95 ! C(CH3)3(ONO) -> C(CH3)3(O) + NO                   
!INTEGER(KIND=JPIM) :: JJ_XXX =  96 ! ClONO -> Cl + NO2                                 
INTEGER(KIND=JPIM) :: JJ_Cl2O2 =  97 ! ClOOCl -> ClOO + Cl


CONTAINS


SUBROUTINE alloc_J
ALLOCATE(J(nphoTUV,ndt_day))
J=0.0_JPRB
ALLOCATE(seq(ndt_day))
seq=1.0_JPRB	! initialised as day
END SUBROUTINE alloc_J

SUBROUTINE dealloc_J
DEALLOCATE(J)
DEALLOCATE(seq)
END SUBROUTINE dealloc_J


SUBROUTINE read_J
!
!  ## Read the TUV file containing photodissociation rates
!  The input file is organized as follows:
!   - 1 header line
!   - nphoTUV description lines, one per reaction
!   - 3 lines of comments
!   - data, one line per time with columns: 
!           time (hours), solar zenith angle, photo-reaction rates
!       for example at 9h15 am the sza is 50.601° and the reaction rates are
!       9.2500     50.601  0.000E+00  1.497E-05  3.790E-04... (for the nhoTUV reactions) 
!
!  ## Interpolate the photodissociation rates at the model daily time steps
!  and evaluate the night/day flag for each step

IMPLICIT NONE

! TUV file content
INTEGER(KIND=JPIM), PARAMETER :: ntmax=60*24	! Max number of time steps in one day
REAL(KIND=JPRB), DIMENSION(nphoTUV,ntmax) :: J_read	! Photodissociation rates
REAL(KIND=JPRB), DIMENSION(ntmax) :: h_read		! Time (hours)
REAL(KIND=JPRB), DIMENSION(ntmax) :: sza_read		! Solar Zenith Angle
INTEGER(KIND=JPIM) ::  nt 			! Actual number of time steps in one day
INTEGER(KIND=JPIM) :: nskTUV			! Number of header lines to skip in the TUVfile before accessing the data
REAL(KIND=JPRB) :: sza
INTEGER(KIND=JPIM) :: l,n,isp
INTEGER(KIND=JPIM) :: ierr
REAL(KIND=JPRB)    :: dtt,ctime,wl,wr

nskTUV=nphoTUV + 4

! read the input file
open(IU_TUV,file=TUVfile,form="formatted",status="old",action="read")
do l=1,nskTUV
   read(IU_TUV,*)
enddo
do l=1,ntmax
   read(IU_TUV,*,iostat=ierr) h_read(l),sza_read(l),(J_read(isp,l),isp=1,nphoTUV)
   if(ierr/=0) then
      write(*,*) 'read_J: problem reading the TUV file / CHECK FORMAT!'
      STOP
   end if
   if ( h_read(l) >= 24. ) exit
   nt=l
enddo
close(IU_TUV)

! interpolate at model times
dtt=24._JPRB/float(ndt_day)
ctime=0.
do n=1,ndt_day
  do l=1,nt-1
     if ( h_read(l).le.ctime .and. h_read(l+1).gt.ctime ) then
        wl = (h_read(l+1) - ctime)/(h_read(l+1)-h_read(l))
        wr = (ctime - h_read(l))/(h_read(l+1)-h_read(l))
        J(:,n) = wl* J_read(:,l) + wr* J_read(:,l+1)
        sza = wl* sza_read(l) + wr* sza_read(l+1)
        if ( sza > 90. ) seq(n)=0.0_JPRB  ! night
        cycle
     endif
     if ( h_read(l+1).eq.ctime ) then
        J(:,n) = J_read(:,l+1)
        sza = sza_read(l+1)
        if ( sza > 90. ) seq(n)=0.0_JPRB  ! night
     endif
  enddo
  ctime=ctime+dtt
enddo


END SUBROUTINE read_J


END MODULE photodis_module
