!  ASIS method 0D Fortran code demonstrator
!
!  Reference:
!    ASIS v1.0: an adaptative solver for the simulation of atmospheric chemistry
!    Daniel Cariolle, Philippe Moinat, Hubert Teyssèdre, Luc Giraud, Béatrice Josse, and Franck Lefèvre
!    Geosci. Model Dev. Discuss., doi:10.5194/gmd-2016-281, 2016
!    Manuscript accepted for publication in the journal Geosci. Model Dev.
!    Published: 21 November 2016
!
!  REACTION RATES FOR THE RACMOBUS SCHEME
!
SUBROUTINE reaction_rates(kq)
!
! This routine calculates the reaction rates for the RACMOBUS scheme
!  Arguments:
!    - kq (IN)             time index (kq=1 --> 00H)
!
!  From modules:
!    - J (IN)              Photodissocation rates read in TUV tables 
!    - seq (IN)            Night / Day 
!    - PHNM (IN)           Air density  molecules/cm3
!    - PH2O (IN)           Water concentration
!    - PT (IN)             Temperature
!    - v_phot (OUT)        Photodissociation rates 
!    - v_3 (OUT)           1 reactant reaction rates 
!    - v_4 (OUT)           2 reactant reaction rates 
!

USE TYPES, ONLY : JPIM,JPRB
USE case_module , ONLY : PHNM,PH2O,PT
USE chemistry_module, ONLY : v_phot,v_3,v_4
USE indices_reactions_module  ! JPO_J*, JP3_*, JP4_* reaction indices
USE photodis_module           ! J, seq and JJ_* indices in the J array

IMPLICIT NONE

INTEGER(KIND=JPIM) :: kq

! local variables
REAL(KIND=JPRB) :: ZK0,ZK2,ZK3,ZE0,ZN0,ZKINF,ZEINF,ZMINF
REAL(KIND=JPRB) :: ZF,ZK0M,Z2KINF,ZFACT,ZAEQ,ZBEQ,BETA
REAL(KIND=JPRB) :: ZKINFT,ZK0T,ZPW,ZK0KINF,Z2HO2


! ----------- Photo-dissociations
!
!
!  NO2  -->  O3P + NO
  v_phot(JPO_JNO2) = J(JJ_NO2,kq)

!  O3  -->  O1D + O2
  v_phot(JPO_JO3a) = J(JJ_O3a,kq)

!  O3  -->  O3P + O2
  v_phot(JPO_JO3b) = J(JJ_O3b,kq)

!  HONO  -->  OH + NO
  v_phot(JPO_JHONO) = J(JJ_HONO,kq)

!  HNO3  -->  OH + NO2
  v_phot(JPO_JHNO3) = J(JJ_HNO3,kq)

!  HNO4  -->  HO2 + NO2
  v_phot(JPO_JHNO4a) = J(JJ_HNO4,kq)*0.65_JPRB

!  HNO4  -->  OH + NO3
  v_phot(JPO_JHNO4b) = J(JJ_HNO4,kq)*0.35_JPRB

!  NO3  -->  NO + O2
  v_phot(JPO_JNO3a) = J(JJ_NO3a,kq)

!  NO3  -->  NO2 + O3P
  v_phot(JPO_JNO3b) = J(JJ_NO3b,kq)

!  H2O2  -->  OH + OH
  v_phot(JPO_JH2O2) = J(JJ_H2O2,kq)

!  HCHO  -->  H2 + CO
  v_phot(JPO_JHCHOa) = J(JJ_HCHOa,kq)

!  HCHO  -->  H + HO2 + CO
  v_phot(JPO_JHCHOb_i) = J(JJ_HCHOb,kq)
  v_phot(JPO_JHCHOb_ii) = v_phot(JPO_JHCHOb_i)

!  ALD  -->  MO2 + HO2 + CO
v_phot(JPO_JALD_i) = 3.67D-6*seq(kq)
v_phot(JPO_JALD_ii) = v_phot(JPO_JALD_i)

!  OP1  -->  CH3O + OH
  v_phot(JPO_JOP1) = J(JJ_OP1,kq)

!  OP2  -->  ALD + HO2 + OH
  v_phot(JPO_JOP2_i) = 4.17D-6*seq(kq)
  v_phot(JPO_JOP2_ii) =v_phot(JPO_JOP2_i)

!  PAA  -->  MO2 + OH
!! --- CROSS SECTIONS: 0.28_JPRB * H2O2 CROSS SECTION
  v_phot(JPO_JPAA_i) = 0.28_JPRB*J(JJ_H2O2,kq);!1.57D-6*seq(kq)
  v_phot(JPO_JPAA_ii) =v_phot(JPO_JPAA_i)
  
!  KET  -->  ACO3 + ETHP
  v_phot(JPO_JKET) = 6.67D-7*seq(kq)
  
!  GLY  -->  0.13_JPRB*HCHO + 1.87_JPRB*CO + 0.87_JPRB*H2
  v_phot(JPO_JGLYa) = 5.83D-5*seq(kq)

!  GLY  -->  0.45_JPRB*HCHO + 1.55_JPRB*CO + 0.80_JPRB*HO2 + 0.15_JPRB*H2
  v_phot(JPO_JGLYb_i) = 2.0D-5*seq(kq)
  v_phot(JPO_JGLYb_ii) =v_phot(JPO_JGLYb_i)

!  MGLY  -->  ACO3 + HO2 + CO
  v_phot(JPO_JMGLY_i) = 9.33D-5*seq(kq)
  v_phot(JPO_JMGLY_ii) =v_phot(JPO_JMGLY_i)
  
!  DCB  -->  TCO3 + HO2
  v_phot(JPO_JDCB) = 4.33D-4*seq(kq)
  
!  ONIT  --> ALD + HO2 + NO2
  v_phot(JPO_JONITa_i) = 0.2_JPRB*2.17D-6*seq(kq)
  v_phot(JPO_JONITa_ii) =v_phot(JPO_JONITa_i)
  
!  ONIT  --> KET + HO2 + NO2
  v_phot(JPO_JONITb_i) = 0.8_JPRB*2.17D-6*seq(kq)
  v_phot(JPO_JONITb_ii) =v_phot(JPO_JONITb_i)
  
!  MACR  -->  HCHO + ACO3 + CO + HO2
  v_phot(JPO_JMACR_i) = 1.33D-6*seq(kq)
  v_phot(JPO_JMACR_ii) =v_phot(JPO_JMACR_i)
  
!  HKET  -->  ACO3 + HCHO + HO2
  v_phot(JPO_JHKET_i) = 6.67D-7*seq(kq)
  v_phot(JPO_JHKET_ii) =v_phot(JPO_JHKET_i)
  
!  O2  -->  O3P + O3P
  v_phot(JPO_JO2) = J(JJ_O2,kq)

!  N2O5  -->  NOx + NOx + XX
  v_phot(JPO_JN2O5) = J(JJ_N2O5a,kq)+J(JJ_N2O5b,kq)

!  H2O  -->  H + OH
  v_phot(JPO_JH2O) = 0._JPRB

!  N2O  -->  N2 + O1D
  v_phot(JPO_JN2O) =J(JJ_N2O,kq)

!  HOCl  -->  Cl + OH
  v_phot(JPO_JHOCl) = J(JJ_HOCl,kq)

!  ClONO2  -->  Cl + NO3
  v_phot(JPO_JClONO2a) = J(JJ_ClONO2a,kq)

!  ClONO2  -->  ClO + NO2
  v_phot(JPO_JClONO2b) = J(JJ_ClONO2b,kq)

!  Cl2O2  -->  Cl + Cl + O2
  v_phot(JPO_JCl2O2_i) = J(JJ_Cl2O2,kq)
  v_phot(JPO_JCl2O2_ii) = v_phot(JPO_JCl2O2_i)

!  HCl  -->  H + Cl
  v_phot(JPO_JHCl) = 0._JPRB

!  Cl2  -->  Cl + Cl
  v_phot(JPO_JCl2) = J(JJ_Cl2,kq)

!  ClNO2  -->  Cl + NO2
  v_phot(JPO_JClNO2) = J(JJ_ClNO2,kq)

!  BrO  -->  Br + O3P
  v_phot(JPO_JBrO) = J(JJ_BrO,kq)

!  BrONO2  -->  Br + NO3
  v_phot(JPO_JBrONO2) = J(JJ_BrONO2a,kq)+J(JJ_BrONO2b,kq)

!  HOBr  -->  Br + OH
  v_phot(JPO_JHOBr) = J(JJ_HOBr,kq)

!  OClO  -->  O3P + ClO
  v_phot(JPO_JOClO) = J(JJ_OClO,kq)

!  BrCl  -->  Br + Cl
  v_phot(JPO_JBrCl) = J(JJ_BrCl,kq)

!  CFC11  -->  Cl + Cl + Cl
  v_phot(JPO_JCFC11_i) = J(JJ_CFC11,kq)
  v_phot(JPO_JCFC11_ii) = v_phot(JPO_JCFC11_i)

!  CFC12  -->  Cl + Cl
  v_phot(JPO_JCFC12) = J(JJ_CFC12,kq)

!  CFC113  -->  Cl + Cl + Cl
  v_phot(JPO_JCFC113_i) = J(JJ_CFC113,kq)
  v_phot(JPO_JCFC113_ii) = v_phot(JPO_JCFC113_i)

!  CCl4  -->  Cl + Cl + Cl + Cl
  v_phot(JPO_JCCl4_i) = J(JJ_CCl4,kq)
  v_phot(JPO_JCCl4_ii) = v_phot(JPO_JCCl4_i)

!  CH3CCl3  -->  Cl + Cl + Cl
  v_phot(JPO_JCH3CCl3_i) = J(JJ_CH3CCl3,kq)
  v_phot(JPO_JCH3CCl3_ii) = v_phot(JPO_JCH3CCl3_i)

!  CH3Cl  -->  Cl
  v_phot(JPO_JCH3Cl) = J(JJ_CH3Cl,kq)

!  HCFC22  -->  Cl
  v_phot(JPO_JHCFC22) = J(JJ_HCFC22,kq)

!  CH3Br  -->  Br
  v_phot(JPO_JCH3Br) = J(JJ_CH3Br,kq)
  
!  H1211  -->  Br
  v_phot(JPO_JH1211) = J(JJ_H1211,kq)

!  H1301  -->  Br
  v_phot(JPO_JH1301) = J(JJ_H1301,kq)

!  NO  -->  N + O3P
  v_phot(JPO_JNO) = 0._JPRB
  !


! ----------- Chemical reactions

!  O3P + O2  -->  O3
  v_4(JP4_O3P_O2) = PHNM*6.00D-34*exp((-2.3_JPRB)*log(PT/300._JPRB))

!  O3P + O3  -->  O2 + O2
  v_4(JP4_O3P_O3)=8.00D-12*exp(-2060.0_JPRB/PT)

!  O1D + N2  -->  O3P + N2
  v_phot(JPO_O1D_N2a) = 2.15D-11*exp( 110.0_JPRB/PT)*0.78_JPRB*PHNM

!  O1D + O2  -->  O3P + O2
  v_4(JP4_O1D_O2) = 3.30D-11*exp( 55.0_JPRB/PT)

!  O1D + H2O  -->  OH + OH
  v_4(JP4_O1D_H2O)=1.63D-10*exp( 60._JPRB/PT)

!  O3 + OH  -->  HO2 + O2
  v_4(JP4_O3_OH)=1.70D-12*exp(-940.0_JPRB/PT)

  !  O3 + HO2  -->  OH + O2 + O2
  v_4(JP4_O3_HO2)=1.00D-14*exp(-490.0_JPRB/PT)

!  OH + HO2  -->  H2O + O2
  v_4(JP4_OH_HO2)=4.80D-11*exp( 250.0_JPRB/PT)

!  H2O2 + OH  -->  HO2 + H2O
  v_4(JP4_H2O2_OH)=1.80D-12

!  HO2 + HO2  -->  H2O2 + O2
  v_3(JP3_HO2_HO2a) = 3.5D-13*exp( 430._JPRB/PT)+1.7D-33*PHNM*exp( 1000._JPRB/PT)


! HO2 + HO2 + H2O --> H2O2 + H2O + O2
  Z2HO2=1.D-24*PHNM*exp( 3200._JPRB/PT)
!  v_3(JP3_HO2_HO2b) = 3.22D-34*exp( 2800._JPRB/PT)+2.38D-30*1.D-24*PHNM*exp(3200.0_JPRB/PT)
  v_3(JP3_HO2_HO2b) = 3.22D-34*exp( 2800._JPRB/PT)+2.38D-30*Z2HO2*PH2O
!
!  O3P + NO  -->  NO2
  ZK0   = 9.00D-32
  ZE0   = 0.0_JPRB
  ZN0   = 1.5_JPRB
  ZKINF = 3.00D-11
  ZEINF = 0.0_JPRB
  ZMINF = 0.0_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_O3P_NO)=(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  O3P + NO2  -->  NO + O2
  v_4(JP4_O3P_NO2a)=5.10D-12*exp( 210.0_JPRB/PT)

!  O3P + NO2  -->  NO3
  ZK0   = 2.5D-31
  ZE0   = 0.0_JPRB
  ZN0   = 1.8_JPRB
  ZKINF = 2.20D-11
  ZEINF = 0.0_JPRB
  ZMINF = 0.7_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_O3P_NO2b)=(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  OH + NO  -->  HONO
  ZK0   = 7.00D-31
  ZE0   = 0.0_JPRB
  ZN0   = 2.6_JPRB
  ZKINF = 3.60D-11
  ZEINF = 0.0_JPRB
  ZMINF = 0.1_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_OH_NO)= (ZK0M/(1.0_JPRB+ZK0M/Z2KINF))*ZFACT
!
!  OH + NO2  -->  HNO3
  ZK0   = 1.80D-30
  ZE0   = 0.0_JPRB
  ZN0   = 3.0_JPRB
  ZKINF = 2.80D-11
  ZEINF = 0.0_JPRB
  ZMINF = 1.7_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_OH_NO2)=(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  OH + NO3  -->  NO2 + HO2
  v_4(JP4_OH_NO3)=2.20D-11
!
!  HO2 + NO  -->  NO2 + OH
  v_4(JP4_HO2_NOa)=3.50D-12*exp( 250.0_JPRB/PT)
!
!  HO2 + NO2  -->  HNO4
  ZK0   = 2.0D-31
  ZE0   = 0.0_JPRB
  ZN0   = 3.4_JPRB
  ZKINF = 2.90D-12
  ZEINF = 0.0_JPRB
  ZMINF = 1.1_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_HO2_NO2)=(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  HNO4  -->  HO2 + NO2
  ZK0   = 2.0D-31
  ZN0   = 3.4_JPRB
  ZKINF = 2.90D-12
  ZMINF = 1.1_JPRB
  ZAEQ  = 2.10D-27
  ZBEQ  = 10900.0_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(0.6_JPRB))
  v_phot(JPO_HNO4) = (1._JPRB/(ZAEQ))*exp(-ZBEQ/PT)*(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  HO2 + NO3  --> HNO3
  v_4(JP4_HO2_NO3a)=0._JPRB
!
!  HO2 + NO3  --> NO2 + OH
  v_4(JP4_HO2_NO3b)=0._JPRB
!
!  OH + HONO  -->  H2O + NO2
!
  v_4(JP4_OH_HONO)= 1.80D-11*exp(-390.0_JPRB/PT)
!
!  OH + HNO3  -->  NO3 + H2O
  ZK0 =2.4D-14*exp( 460._JPRB/PT)
  ZK2 =2.7D-17*exp(2199._JPRB/PT)
  ZK3 =6.5D-34*PHNM*exp(1335._JPRB/PT)
  v_4(JP4_OH_HNO3)=ZK0 + ZK3/(1._JPRB+ZK3/ZK2)
!
!  OH + HNO4  -->  NO2 + H2O + O2
  v_4(JP4_OH_HNO4)=1.30D-12*exp( 380.0_JPRB/PT)

!  O3 + NO  -->  NO2 + O2
  v_4(JP4_O3_NO)=2.00D-12*exp(-1400.0_JPRB/PT)
!
!  O3 + NO2  -->  NO3 + O2
  v_4(JP4_O3_NO2)=1.20D-13*exp(-2450.0_JPRB/PT)
!
!  NO + NO + O2  -->  NO2 + NO2
  v_3(JP3_NO_NO)=0._JPRB;! 3.30D-39*exp(530.0_JPRB/PT)*PHNM
!
!  NO3 + NO  -->  NO2 + NO2
  v_4(JP4_NO3_NO)=1.50D-11*exp( 170.0_JPRB/PT)
!
!  NO3 + NO2  -->  NO + NO2 + O2
  v_4(JP4_NO3_NO2a)=4.50D-14*exp(-1260.0_JPRB/PT)
!
!  NO3 + NO2  -->  N2O5
  ZK0   = 2.0D-30
  ZE0   = 0.0_JPRB
  ZN0   = 4.4_JPRB
  ZKINF = 1.40D-12
  ZEINF = 0.0_JPRB
  ZMINF = 0.7_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_NO3_NO2b)=(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  N2O5  -->  NO2 + NO3
  ZK0   = 2.00D-30
  ZN0   = 4.4_JPRB
  ZKINF = 1.40D-12
  ZMINF = 0.7_JPRB
  ZAEQ  = 2.70D-27
  ZBEQ  = 11000.0_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(0.6_JPRB))
  v_phot(JPO_N2O5) = (1._JPRB/(ZAEQ))*exp(-ZBEQ/PT)*(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  NO3 + NO3  -->  NO2 + NO2 + O2
  v_3(JP3_NO3_NO3_i) = 8.50D-13*exp(-2450.0_JPRB/PT)
  v_3(JP3_NO3_NO3_ii) = v_3(JP3_NO3_NO3_i) 
!
!  OH + H2  -->  H2O + H
  v_phot(JPO_OH_H2)=2.80D-12*exp(-1800.0_JPRB/PT)*5.D-07*PHNM
!
!  OH + SO2  -->  SULF + HO2
!
  ZK0   = 3.00D-31
  ZE0   = 0.0_JPRB
  ZN0   = 3.3_JPRB
  ZKINF = 1.50D-12
  ZEINF = 0.0_JPRB
  ZMINF = 0.0_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_OH_SO2) = (ZK0M/(1.0_JPRB+ZK0M/Z2KINF))*ZFACT
!
!  CO + OH  -->  H + CO2
!  ZK0T    = 1.5D-13*(PT/300._JPRB)**0.6_JPRB
  ZK0T    = 1.5D-13*exp(0.6_JPRB*log((PT/300._JPRB)))
  ZKINFT  = 2.1D+09*exp(6.1_JPRB*log((PT/300._JPRB)))
  ZK0KINF = ZK0T/(ZKINFT/PHNM)
  ZPW     = 1._JPRB/(1._JPRB+(log10(ZK0KINF))*(log10(ZK0KINF)))
  v_4(JP4_CO_OHa)=(ZK0T/(1._JPRB+ZK0KINF))*exp(ZPW*log(0.6_JPRB))
!
!  ISO + O3P  -->  0.86_JPRB*OLT + 0.05_JPRB*HCHO + 0.02_JPRB*OH + 0.01_JPRB*CO +
!                0.13_JPRB*DCB + 0.28_JPRB*HO2 + 0.15_JPRB*XO2
  v_4(JP4_ISO_O3P_i) = 6.00D-11
  v_4(JP4_ISO_O3P_ii) =v_4(JP4_ISO_O3P_i)
  v_4(JP4_ISO_O3P_iii) =v_4(JP4_ISO_O3P_i)
  v_4(JP4_ISO_O3P_iv) =v_4(JP4_ISO_O3P_i)
!
!  MACR + O3P  -->  ALD
!
  v_4(JP4_MACR_O3P) = 1.59D-11*exp(13.0_JPRB/PT)
!
! CH4 + OH  -->  CH3 + H2O
  v_4(JP4_CH4_OH)=2.80D-14*exp(0.667_JPRB*log(PT))*exp(-1575._JPRB/PT)
!
!  ETH + OH  -->  ETHP + H2O
!
  v_4(JP4_ETH_OH) = PT*PT*1.51D-17*exp(-492._JPRB/PT)
!
!  HC3 + OH  -->  0.583_JPRB*HC3P + 0.381_JPRB*HO2 + 0.335_JPRB*ALD +
!                0.036_JPRB*ORA1 + 0.036_JPRB*CO + 0.036_JPRB*GLY + 0.036_JPRB*OH + 0.010_JPRB*HCHO + H2O

  v_4(JP4_HC3_OH_i) = 5.26D-12*exp(-260.0_JPRB/PT)
  v_4(JP4_HC3_OH_ii)  =v_4(JP4_HC3_OH_i)
  v_4(JP4_HC3_OH_iii) =v_4(JP4_HC3_OH_i)
  v_4(JP4_HC3_OH_iv)  =v_4(JP4_HC3_OH_i)
!
!  HC5 + OH  --> HC5P + H2O
  v_4(JP4_HC5_OHa) = 0.750_JPRB*8.02D-12*exp(-155.0_JPRB/PT)
!
!  HC5 + OH  --> KET + HO2 + H2O
  v_4(JP4_HC5_OHb) = 0.250_JPRB*8.02D-12*exp(-155.0_JPRB/PT)
!
!  HC8 + OH  -->  0.951_JPRB*HC8P + 0.025_JPRB*ALD + 0.024_JPRB*HKET + 0.049_JPRB*HO2 + H2O
  v_4(JP4_HC8_OH_i) = 1.64D-11*exp(-125.0_JPRB/PT)
  v_4(JP4_HC8_OH_ii) =v_4(JP4_HC8_OH_i)
!
!  ETE + OH  -->  ETEP
  v_4(JP4_ETE_OH) = 1.96D-12*exp(438.0_JPRB/PT)
!
!  OLT + OH  -->  OLTP
  v_4(JP4_OLT_OH) = 5.72D-12*exp(500.0_JPRB/PT)
!
!  OLI + OH  -->  OLIP
   v_4(JP4_OLI_OH) = 1.33D-11*(500.0_JPRB/PT)
!
!  DIEN + OH  -->  ISOP
   v_4(JP4_DIEN_OH) = 1.48D-11*exp(448.0_JPRB/PT)
!
!  ISO + OH  -->  ISOP
   v_4(JP4_ISO_OH) = 2.54D-11*exp(410.0_JPRB/PT)
!
!  API + OH  -->  APIP
   v_4(JP4_API_OH) = 1.21D-11*exp(444.0_JPRB/PT)
!
!  LIM + OH  -->  LIMP
   v_4(JP4_LIM_OH) = 1.71D-10
!
!  TOL + OH  --> ADDT
   v_4(JP4_TOL_OHa) = 0.90_JPRB*1.81D-12*exp(355.0_JPRB/PT)
!
!  TOL + OH  --> XO2 + HO2
   v_4(JP4_TOL_OHb) = 0.10_JPRB*1.81D-12*exp(355.0_JPRB/PT)
!
!  XYL + OH  --> ADDX
   v_4(JP4_XYL_OHa) = 0.90_JPRB*7.30D-12*exp(355.0_JPRB/PT)
!
!  XYL + OH  --> XO2 + HO2
   v_4(JP4_XYL_OHb) = 0.10_JPRB*7.30D-12*exp(355.0_JPRB/PT)
!
!  CSL + OH  --> ADDC
   v_4(JP4_CSL_OHa) = 0.85_JPRB*6.00D-11
!
!  CSL + OH  --> PHO
   v_4(JP4_CSL_OHb) = 0.10_JPRB*6.00D-11
!
!  CSL + OH  --> HO2 + XO2
   v_4(JP4_CSL_OHc) = 0.05_JPRB*6.00D-11
!
!  HCHO + OH  -->  HO2 + CO + H2O
   v_4(JP4_HCHO_OH_i) = 1.00D-11
   v_4(JP4_HCHO_OH_ii)=v_4(JP4_HCHO_OH_i)
!
!  ALD + OH  -->  ACO3 + H2O
   v_4(JP4_ALD_OH) = 5.55D-12*exp(331.0_JPRB/PT)
!
!  KET + OH  -->  KETP + H2O
   v_4(JP4_KET_OH) = PT*PT*5.68D-18*exp(92.0_JPRB/PT)
!
!  HKET + OH  -->  HO2 + MGLY + H2O
   v_4(JP4_HKET_OH) = 3.00D-12
!
!  GLY + OH  -->  HO2 + CO + CO + H2O
   v_4(JP4_GLY_OH) = 1.14D-11
!
!  MGLY + OH  -->  ACO3 + CO + H2O
   v_4(JP4_MGLY_OH) = 1.72D-11
!
!  MACR + OH  -->  0.51_JPRB*TCO3 + 0.41_JPRB*HKET + 0.08_JPRB*MGLY + 0.41_JPRB*CO +
!                0.08_JPRB*HCHO + 0.49_JPRB*HO2 + 0.49_JPRB*XO2
   v_4(JP4_MACR_OH_i) = 1.86D-11*exp(175.0_JPRB/PT)
   v_4(JP4_MACR_OH_ii) =v_4(JP4_MACR_OH_i)
   v_4(JP4_MACR_OH_iii) =v_4(JP4_MACR_OH_i)
   v_4(JP4_MACR_OH_iv) =v_4(JP4_MACR_OH_i)
!
!  OH + DCB  -->  0.50_JPRB*TCO3 + 0.50_JPRB*HO2 + 0.50_JPRB*XO2 + 0.35_JPRB*UDD +
!                0.15_JPRB*GLY + 0.15_JPRB*MGLY
   v_4(JP4_OH_DCB_i) = 2.80D-11 *exp(175.0_JPRB /PT)
   v_4(JP4_OH_DCB_ii) =v_4(JP4_OH_DCB_i)
   v_4(JP4_OH_DCB_iii) =v_4(JP4_OH_DCB_i)
!
!  OH + UDD  --> ALD + HO2
   v_4(JP4_OH_UDDa) = 0.88_JPRB*2.70D-10
!
!  OH + UDD  --> KET + HO2
   v_4(JP4_OH_UDDb) = 0.12_JPRB*2.70D-10
!
!  OP1 + OH  --> MO2 + H2O
   v_4(JP4_OP1_OHa)=0.65_JPRB*2.93D-12*exp(190.0_JPRB/PT);!3.8D-12*exp( 200._JPRB/PT)
!
!  OP1 + OH  --> HCHO + OH + H2O
   v_4(JP4_OP1_OHb_i) =0.35_JPRB*2.93D-12*exp(190.0_JPRB/PT);!3.8D-12*exp( 200._JPRB/PT)
   v_4(JP4_OP1_OHb_ii)=v_4(JP4_OP1_OHb_i)
!
!  OP2 + OH  -->  0.44_JPRB*HC3P + 0.08_JPRB*ALD + 0.49_JPRB*OH + 0.07_JPRB*XO2 + 0.41_JPRB*KET
   v_4(JP4_OP2_OH_i) = 3.40D-12*exp(190.0_JPRB/PT)
   v_4(JP4_OP2_OH_ii) =v_4(JP4_OP2_OH_i)
   v_4(JP4_OP2_OH_iii) =v_4(JP4_OP2_OH_i)
!
!  PAA + OH  --> ACO3
   v_4(JP4_PAA_OHa) = 0.65_JPRB*2.93D-12*exp(190.0_JPRB/PT)
!
!  PAA + OH  --> HO2 + HCHO + XO2
   v_4(JP4_PAA_OHb_i) = 0.35_JPRB*2.93D-12*exp(190.0_JPRB/PT)
   v_4(JP4_PAA_OHb_ii) =v_4(JP4_PAA_OHb_i)
!
!  PAN + OH  -->  HCHO + NO3 + XO2 + H2O
   v_4(JP4_PAN_OH_i) = 4.00D-14
   v_4(JP4_PAN_OH_ii) =v_4(JP4_PAN_OH_i)
!
!  TPAN + OH  -->  0.60_JPRB*HKET + 0.60_JPRB*NO3 + 0.40_JPRB*PAN + 0.40_JPRB*HCHO + 0.40_JPRB*HO2 + XO2
   v_4(JP4_TPAN_OH_i) = 3.25D-13*exp(500.0_JPRB/PT)
   v_4(JP4_TPAN_OH_ii) =v_4(JP4_TPAN_OH_i)
   v_4(JP4_TPAN_OH_iii) =v_4(JP4_TPAN_OH_i)
!
!  ONIT + OH  -->  HC3P + NO2 + H2O
   v_4(JP4_ONIT_OH_i) = 5.31D-12 *exp(-(260.0_JPRB /PT))
   v_4(JP4_ONIT_OH_ii) =v_4(JP4_ONIT_OH_i)
!
!  HCHO + NO3  -->  HO2 + HNO3 + CO
   v_4(JP4_HCHO_NO3_i) = 3.40D-13 *exp(-(1900.0_JPRB /PT))
   v_4(JP4_HCHO_NO3_ii) =v_4(JP4_HCHO_NO3_i)
!
!  ALD + NO3  -->  ACO3 + HNO3
!
   v_4(JP4_ALD_NO3) = 1.40D-12 *exp(-(1900.0_JPRB /PT))
!
!  GLY + NO3  -->  HNO3 + HO2 + CO + CO
   v_4(JP4_GLY_NO3_i) = 2.90D-12 *exp(-(1900.0_JPRB /PT))
   v_4(JP4_GLY_NO3_ii) =v_4(JP4_GLY_NO3_i)
!
!  MGLY + NO3  -->  HNO3 + ACO3 + CO
   v_4(JP4_MGLY_NO3_i) = 1.40D-12 *exp(-(1900.0_JPRB /PT))
   v_4(JP4_MGLY_NO3_ii) =v_4(JP4_MGLY_NO3_i)
!
!  MACR + NO3  -->  0.20_JPRB*TCO3 + 0.20_JPRB*HNO3 + 0.80_JPRB*OLNN + 0.80_JPRB*CO
   v_4(JP4_MACR_NO3_i) = 8.27D-15 *exp(-(150.0_JPRB /PT))
   v_4(JP4_MACR_NO3_ii) =v_4(JP4_MACR_NO3_i)
!
!  DCB + NO3  -->  0.50_JPRB*TCO3 + 0.50_JPRB*HO2 + 0.50_JPRB*XO2 + 0.25_JPRB*GLY +
!                0.25_JPRB*ALD + 0.50_JPRB*NO2 + 0.03_JPRB*KET + 0.25_JPRB*MGLY + 0.50_JPRB*HNO3
   v_4(JP4_DCB_NO3_i) = 2.87D-13 *exp(-(1000.0_JPRB /PT))
   v_4(JP4_DCB_NO3_ii) =v_4(JP4_DCB_NO3_i)
   v_4(JP4_DCB_NO3_iii) =v_4(JP4_DCB_NO3_i)
   v_4(JP4_DCB_NO3_iv) =v_4(JP4_DCB_NO3_i)
   v_4(JP4_DCB_NO3_v) =v_4(JP4_DCB_NO3_i)
!
!  CSL + NO3  -->  HNO3 + PHO
!
   v_4(JP4_CSL_NO3) = 2.20D-11 
!
!  ETE + NO3  --> OLNN
   v_4(JP4_ETE_NO3a) = 0.80_JPRB *PT*PT*4.88D-18 *exp(-(2282.0_JPRB /PT))
!
!  ETE + NO3  --> OLND
   v_4(JP4_ETE_NO3b) = 0.20_JPRB *PT*PT*4.88D-18 *exp(-(2282.0_JPRB /PT))
!
!  OLT + NO3  --> OLNN
   v_4(JP4_OLT_NO3a) = 0.43_JPRB *1.79D-13 *exp(-(450.0_JPRB /PT))
!
!  OLT + NO3  --> OLND
   v_4(JP4_OLT_NO3b) = 0.57_JPRB *1.79D-13 *exp(-(450.0_JPRB /PT))
!
!  OLI + NO3  --> OLNN
   v_4(JP4_OLI_NO3a) = 0.11_JPRB *8.64D-13 *exp(450.0_JPRB /PT)
!
!  OLI + NO3  --> OLND
   v_4(JP4_OLI_NO3b) = 0.89_JPRB *8.64D-13 *exp(450.0_JPRB /PT)
!
!  DIEN + NO3  --> OLNN + MACR
   v_4(JP4_DIEN_NO3a) = 0.90_JPRB *1.00D-13 
!
!  DIEN + NO3  --> OLND
   v_4(JP4_DIEN_NO3b) = 0.10_JPRB *1.00D-13 
!
!  ISO + NO3  --> OLNN + MACR
   v_4(JP4_ISO_NO3a) = 0.90_JPRB *4.00D-12 *exp(-(446.0_JPRB /PT))
!
!  ISO + NO3  --> OLND
   v_4(JP4_ISO_NO3b) = 0.10_JPRB *4.00D-12 *exp(-(446.0_JPRB /PT))
!
!  API + NO3  --> OLNN
   v_4(JP4_API_NO3a) = 0.10_JPRB *1.19D-12 *exp(490.0_JPRB /PT)
!
!  API + NO3  --> OLND
   v_4(JP4_API_NO3b) = 0.90_JPRB *1.19D-12 *exp(490.0_JPRB /PT)
!
!  LIM + NO3  --> OLNN
   v_4(JP4_LIM_NO3a) = 0.13_JPRB *1.22D-11 
!
!  LIM + NO3  --> OLND
   v_4(JP4_LIM_NO3b) = 0.87_JPRB *1.22D-11
!
!  TPAN + NO3  -->  ONIT + NO3 + XO2
   v_4(JP4_TPAN_NO3a_i) = 0.60_JPRB *2.20D-14 *exp(-(500.0_JPRB /PT))
   v_4(JP4_TPAN_NO3a_ii) =v_4(JP4_TPAN_NO3a_i)
!
!  TPAN + NO3  -->  PAN + HCHO + NO2 + XO2
   v_4(JP4_TPAN_NO3b_i) = 0.40_JPRB *2.20D-14 *exp(-(500.0_JPRB /PT))
   v_4(JP4_TPAN_NO3b_ii) =v_4(JP4_TPAN_NO3b_i)
!
!  ETE + O3  -->  HCHO + 0.43_JPRB*CO + 0.37_JPRB*ORA1 + 0.26_JPRB*HO2 + 0.13_JPRB*H2 + 0.12_JPRB*OH
   v_4(JP4_ETE_O3_i) = 9.14D-15 *exp(-(2580.0_JPRB /PT))
   v_4(JP4_ETE_O3_ii) =v_4(JP4_ETE_O3_i)
   v_4(JP4_ETE_O3_iii) =v_4(JP4_ETE_O3_i)
!
!  OLT + O3  -->  0.64_JPRB*HCHO + 0.44_JPRB*ALD + 0.37_JPRB*CO + 0.14_JPRB*ORA1 +
!                0.10_JPRB*ORA2 + 0.25_JPRB*HO2 + 0.40_JPRB*OH + 0.03_JPRB*KET + 0.03_JPRB*KETP +
!                0.06_JPRB*CH4 + 0.05_JPRB*H2 + 0.03_JPRB*ETH + 0.006_JPRB*H2O2 + 0.19_JPRB*MO2 +
!                0.10_JPRB*ETHP
   v_4(JP4_OLT_O3_i) = 4.33D-15 *exp(-(1800.0_JPRB /PT))
   v_4(JP4_OLT_O3_ii) =v_4(JP4_OLT_O3_i)
   v_4(JP4_OLT_O3_iii) =v_4(JP4_OLT_O3_i)
   v_4(JP4_OLT_O3_iv) =v_4(JP4_OLT_O3_i)
   v_4(JP4_OLT_O3_v) =v_4(JP4_OLT_O3_i)
   v_4(JP4_OLT_O3_vi) =v_4(JP4_OLT_O3_i)
   v_4(JP4_OLT_O3_vii) =v_4(JP4_OLT_O3_i)
!
!  OLI + O3  -->  0.02_JPRB*HCHO + 0.99_JPRB*ALD + 0.16_JPRB*KET + 0.30_JPRB*CO +
!                0.011_JPRB*H2O2 + 0.14_JPRB*ORA2 + 0.07_JPRB*CH4 + 0.22_JPRB*HO2 + 0.63_JPRB*OH +
!                0.23_JPRB*MO2 + 0.12_JPRB*KETP + 0.06_JPRB*ETH + 0.18_JPRB*ETHP
   v_4(JP4_OLI_O3_i) = 4.40D-15 *exp(-(845.0_JPRB /PT))
   v_4(JP4_OLI_O3_ii) =v_4(JP4_OLI_O3_i)
   v_4(JP4_OLI_O3_iii) =v_4(JP4_OLI_O3_i)
   v_4(JP4_OLI_O3_iv) =v_4(JP4_OLI_O3_i)
   v_4(JP4_OLI_O3_v) =v_4(JP4_OLI_O3_i)
   v_4(JP4_OLI_O3_vi) =v_4(JP4_OLI_O3_i)
!
!  DIEN + O3  -->  0.90_JPRB*HCHO + 0.39_JPRB*MACR + 0.36_JPRB*CO + 0.15_JPRB*ORA1 +
!                0.09_JPRB*O3P + 0.30_JPRB*HO2 + 0.35_JPRB*OLT + 0.28_JPRB*OH + 0.05_JPRB*H2 + 0.15_JPRB*ACO3
!                0.03_JPRB*MO2 + 0.02_JPRB*KETP + 0.13_JPRB*XO2 + 0.001_JPRB*H2O2
   v_4(JP4_DIEN_O3_i) = 1.34D-14 *exp(-(2283.0_JPRB /PT))
   v_4(JP4_DIEN_O3_ii) =v_4(JP4_DIEN_O3_i)
   v_4(JP4_DIEN_O3_iii) =v_4(JP4_DIEN_O3_i)
   v_4(JP4_DIEN_O3_iv) =v_4(JP4_DIEN_O3_i)
   v_4(JP4_DIEN_O3_v) =v_4(JP4_DIEN_O3_i)
   v_4(JP4_DIEN_O3_vi) =v_4(JP4_DIEN_O3_i)
!
!  ISO + O3  -->  0.90_JPRB*HCHO + 0.39_JPRB*MACR + 0.36_JPRB*CO + 0.15_JPRB*ORA1 +
!                0.09_JPRB*O3P + 0.30_JPRB*HO2 + 0.35_JPRB*OLT + 0.28_JPRB*OH + 0.05_JPRB*H2 + 0.15_JPRB*ACO3
!                0.03_JPRB*MO2 + 0.02_JPRB*KETP + 0.13_JPRB*XO2 + 0.001_JPRB*H2O2
   v_4(JP4_ISO_O3_i) = 7.86D-15 *exp(-(1913.0_JPRB /PT))
   v_4(JP4_ISO_O3_ii) =v_4(JP4_ISO_O3_i)
   v_4(JP4_ISO_O3_iii) =v_4(JP4_ISO_O3_i)
   v_4(JP4_ISO_O3_iv) =v_4(JP4_ISO_O3_i)
   v_4(JP4_ISO_O3_v) =v_4(JP4_ISO_O3_i)
   v_4(JP4_ISO_O3_vi) =v_4(JP4_ISO_O3_i)
!
!  API + O3  -->  0.65_JPRB*ALD + 0.53_JPRB*KET + 0.14_JPRB*CO + 0.20_JPRB*ETHP +
!                0.42_JPRB*KETP + 0.85_JPRB*OH + 0.10_JPRB*HO2 + 0.02_JPRB*H2O2
   v_4(JP4_API_O3_i) = 1.01D-15 *exp(-(736.0_JPRB /PT))
   v_4(JP4_API_O3_ii) =v_4(JP4_API_O3_i)
   v_4(JP4_API_O3_iii) =v_4(JP4_API_O3_i)
   v_4(JP4_API_O3_iv) =v_4(JP4_API_O3_i)
!
!  LIM + O3  -->  0.04_JPRB*HCHO + 0.46_JPRB*OLT + 0.14_JPRB*CO + 0.16_JPRB*ETHP +
!                0.42_JPRB*KETP + 0.85_JPRB*OH + 0.10_JPRB*HO2 + 0.02_JPRB*H2O2 + 0.79_JPRB*MACR +
!                0.01_JPRB*ORA1 + 0.07_JPRB*ORA2
   v_4(JP4_LIM_O3_i) = 2.00D-16
   v_4(JP4_LIM_O3_ii) =v_4(JP4_LIM_O3_i)
   v_4(JP4_LIM_O3_iii) =v_4(JP4_LIM_O3_i)
   v_4(JP4_LIM_O3_iv) =v_4(JP4_LIM_O3_i)
   v_4(JP4_LIM_O3_v) =v_4(JP4_LIM_O3_i)
!   
!  MACR + O3  -->  0.40_JPRB*HCHO + 0.60_JPRB*MGLY + 0.13_JPRB*ORA2 + 0.54_JPRB*CO +
!                0.08_JPRB*H2 + 0.22_JPRB*ORA1 + 0.29_JPRB*HO2 + 0.07_JPRB*OH + 0.13_JPRB*OP2 + 0.13_JPRB*ACO3
   v_4(JP4_MACR_O3_i) = 1.36D-15 *exp(-(2112.0_JPRB /PT))
   v_4(JP4_MACR_O3_ii) =v_4(JP4_MACR_O3_i)
   v_4(JP4_MACR_O3_iii) =v_4(JP4_MACR_O3_i)
   v_4(JP4_MACR_O3_iv) =v_4(JP4_MACR_O3_i)
   v_4(JP4_MACR_O3_v) =v_4(JP4_MACR_O3_i)
!
!  DCB + O3  -->  0.21_JPRB*OH + 0.29_JPRB*HO2 + 0.66_JPRB*CO + 0.50_JPRB*GLY +
!                0.62_JPRB*MGLY + 0.28_JPRB*ACO3 + 0.16_JPRB*ALD + 0.11_JPRB*PAA + 0.11_JPRB*ORA1 +
!                0.21_JPRB*ORA2
   v_4(JP4_DCB_O3_i) = 2.00D-18
   v_4(JP4_DCB_O3_ii) =v_4(JP4_DCB_O3_i)
   v_4(JP4_DCB_O3_iii) =v_4(JP4_DCB_O3_i)
   v_4(JP4_DCB_O3_iv) =v_4(JP4_DCB_O3_i)
!
!  TPAN + O3  -->  0.70_JPRB*HCHO + 0.30_JPRB*PAN + 0.70_JPRB*NO2 + 0.13_JPRB*CO +
!                0.04_JPRB*H2 + 0.11_JPRB*ORA1 + 0.08_JPRB*HO2 + 0.036_JPRB*OH + 0.70_JPRB*ACO3
   v_4(JP4_TPAN_O3_i) = 2.46D-15 *exp(-(1700.0_JPRB /PT))
   v_4(JP4_TPAN_O3_ii) =v_4(JP4_TPAN_O3_i)
   v_4(JP4_TPAN_O3_iii) =v_4(JP4_TPAN_O3_i)
   v_4(JP4_TPAN_O3_iv) =v_4(JP4_TPAN_O3_i)
!
!  PHO + NO2  -->  0.10_JPRB*CSL + ONIT
   v_4(JP4_PHO_NO2) = 2.00D-11
!
!  PHO + HO2  -->  CSL
   v_4(JP4_PHO_HO2) = 1.00D-11 
!
!  ADDT + NO2  -->  CSL + HONO
   v_4(JP4_ADDT_NO2) = 3.60D-11
!
!  ADDT + O2  --> TOLP
   v_4(JP4_ADDT_O2a) = 0.98_JPRB *1.66D-17 *exp(1044.0_JPRB /PT)
!
!  ADDT + O2  --> CSL + HO2
   v_4(JP4_ADDT_O2b) = 0.02_JPRB *1.66D-17 *exp(1044.0_JPRB /PT)
!
!  ADDT + O3  -->  CSL + OH
   v_4(JP4_ADDT_O3) = 5.00D-11
!
!  ADDX + NO2  -->  CSL + HONO
   v_4(JP4_ADDX_NO2) = 3.60D-11
!
!  ADDX + O2  --> XYLP
   v_4(JP4_ADDX_O2a) = 0.98_JPRB *1.66D-17 *exp(1044.0_JPRB /PT)
!
!  ADDX + O2  --> CSL + HO2
   v_4(JP4_ADDX_O2b) = 0.02_JPRB *1.66D-17 *exp(1044.0_JPRB /PT)
!
!  ADDX + O3  -->  CSL + OH
   v_4(JP4_ADDX_O3) = 1.00D-11
!
!  ADDC + NO2  -->  CSL + HONO
   v_4(JP4_ADDC_NO2) = 3.60D-11
!
!  ADDC + O2  --> CSLP
   v_4(JP4_ADDC_O2a) = 0.98_JPRB *1.66D-17 *exp(1044.0_JPRB /PT)
!
!  ADDC + O2  --> CSL + HO2
   v_4(JP4_ADDC_O2b) = 0.02_JPRB *1.66D-17 *exp(1044.0_JPRB /PT)
!
!  ADDC + O3  -->  CSL + OH
   v_4(JP4_ADDC_O3) = 5.00D-11
!
!  ACO3 + NO2  -->  PAN
  ZK0   = 9.70D-29
  ZE0   = 0.0_JPRB
  ZN0   = 5.6_JPRB
  ZKINF = 9.30D-12
  ZEINF = 0.0_JPRB
  ZMINF = 1.5_JPRB
  ZF    = 0.6_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
  v_4(JP4_ACO3_NO2) = (ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  PAN  -->  ACO3 + NO2
  ZK0   = 9.70D-29
  ZN0   = 5.6_JPRB
  ZKINF = 9.30D-12
  ZMINF = 1.5_JPRB
  ZAEQ  = 8.60D-29
  ZBEQ  = 13954.0_JPRB
  ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))
  Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))
  ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(0.6_JPRB))
  v_phot(JPO_PAN) = (1._JPRB/(ZAEQ))*exp(-ZBEQ/PT)*(ZK0M/(1._JPRB+ZK0M/Z2KINF))*ZFACT
!
!  TCO3 + NO2  -->  TPAN
   ZK0   = 9.70D-29 
   ZE0   = 0.0_JPRB 
   ZN0   = 5.6_JPRB 
   ZKINF = 9.30D-12 
   ZEINF = 0.0_JPRB 
   ZMINF = 1.5_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_4(JP4_TCO3_NO2) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  TPAN  -->  TCO3 + NO2
!
   ZK0   = 9.70D-29 
   ZN0   = 5.6_JPRB 
   ZKINF = 9.30D-12 
   ZMINF = 1.5_JPRB 
   ZAEQ  = 8.60D-29 
   ZBEQ  = 13954.0_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(0.6_JPRB))
   v_phot(JPO_TPAN) = (1.0_JPRB /(ZAEQ))*exp(-ZBEQ/PT)*(ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  MO2 + NO  -->  CH3O + NO2
   v_4(JP4_MO2_NO) =4.20D-12*exp(180.0_JPRB/PT);! 3.0D-12 *exp(280.0_JPRB /PT)
!
!  ETHP + NO  -->  ALD + HO2 + NO2
   v_4(JP4_ETHP_NO_i) = 8.70D-12
   v_4(JP4_ETHP_NO_ii) =v_4(JP4_ETHP_NO_i)
!
!  HC3P + NO  -->  0.047_JPRB*HCHO + 0.233_JPRB*ALD + 0.623_JPRB*KET +
!                0.063_JPRB*GLY + 0.742_JPRB*HO2 + 0.150_JPRB*MO2 + 0.048_JPRB*ETHP + 0.048_JPRB*XO2 +
!                0.059_JPRB*ONIT + 0.941_JPRB*NO2
   v_4(JP4_HC3P_NO_i) = 4.00D-12
   v_4(JP4_HC3P_NO_ii) =v_4(JP4_HC3P_NO_i)
   v_4(JP4_HC3P_NO_iii) =v_4(JP4_HC3P_NO_i)
   v_4(JP4_HC3P_NO_iv) =v_4(JP4_HC3P_NO_i)
   v_4(JP4_HC3P_NO_v) =v_4(JP4_HC3P_NO_i)
!
!  HC5P + NO  -->  0.021_JPRB*HCHO + 0.211_JPRB*ALD + 0.722_JPRB*KET +
!                0.599_JPRB*HO2 + 0.031_JPRB*MO2 + 0.245_JPRB*ETHP + 0.334_JPRB*XO2 + 0.124_JPRB*ONIT +
!                0.876_JPRB*NO2
   v_4(JP4_HC5P_NO_i) = 4.00D-12 
   v_4(JP4_HC5P_NO_ii) = v_4(JP4_HC5P_NO_i)
   v_4(JP4_HC5P_NO_iii) = v_4(JP4_HC5P_NO_i)
   v_4(JP4_HC5P_NO_iv) = v_4(JP4_HC5P_NO_i)
   v_4(JP4_HC5P_NO_v) = v_4(JP4_HC5P_NO_i)
!
!  HC8P + NO  -->  0.150_JPRB*ALD + 0.642_JPRB*KET + 0.133_JPRB*ETHP +
!                0.261_JPRB*ONIT + 0.739_JPRB*NO2 + 0.606_JPRB*HO2 + 0.416_JPRB*XO2
   v_4(JP4_HC8P_NO_i) = 4.00D-12 
   v_4(JP4_HC8P_NO_ii) =v_4(JP4_HC8P_NO_i)
   v_4(JP4_HC8P_NO_iii) =v_4(JP4_HC8P_NO_i)
   v_4(JP4_HC8P_NO_iv) =v_4(JP4_HC8P_NO_i)
!
!  ETEP + NO  -->  1.6_JPRB*HCHO + HO2 + NO2 + 0.2_JPRB*ALD
   v_4(JP4_ETEP_NO_i) = 9.00D-12
   v_4(JP4_ETEP_NO_ii) =v_4(JP4_ETEP_NO_i)
!
!  OLTP + NO  -->  0.94_JPRB*ALD + HCHO + HO2 + NO2 + 0.06_JPRB*KET
   v_4(JP4_OLTP_NO_i) = 4.00D-12
   v_4(JP4_OLTP_NO_ii) =v_4(JP4_OLTP_NO_i)
   v_4(JP4_OLTP_NO_iii) =v_4(JP4_OLTP_NO_i)
!
!  OLIP + NO  -->  HO2 + 1.71_JPRB*ALD + 0.29_JPRB*KET + NO2
   v_4(JP4_OLIP_NO_i) = 4.00D-12
   v_4(JP4_OLIP_NO_ii) =v_4(JP4_OLIP_NO_i)
!
!  ISOP + NO  -->  0.446_JPRB*MACR + 0.354_JPRB*OLT + 0.847_JPRB*HO2 +
!                0.847_JPRB*NO2 + 0.153_JPRB*ONIT + 0.606_JPRB*HCHO
   v_4(JP4_ISOP_NO_i) = 4.00D-12
   v_4(JP4_ISOP_NO_ii) =v_4(JP4_ISOP_NO_i)
   v_4(JP4_ISOP_NO_iii) =v_4(JP4_ISOP_NO_i)
!
!  APIP + NO  -->  0.80_JPRB*HO2 + 0.80_JPRB*ALD + 0.80_JPRB*NO2 + 0.80_JPRB*KET + 0.20_JPRB*ONIT
   v_4(JP4_APIP_NO_i) = 4.00D-12
   v_4(JP4_APIP_NO_ii) =v_4(JP4_APIP_NO_i)
   v_4(JP4_APIP_NO_iii) =v_4(JP4_APIP_NO_i)
!
!  LIMP + NO  -->  0.65_JPRB*HO2 + 0.40_JPRB*MACR + 0.25_JPRB*OLI + 0.25_JPRB*HCHO +
!                0.65_JPRB*NO2 + 0.35_JPRB*ONIT
   v_4(JP4_LIMP_NO_i) = 4.00D-12
   v_4(JP4_LIMP_NO_ii) =v_4(JP4_LIMP_NO_i)
   v_4(JP4_LIMP_NO_iii) =v_4(JP4_LIMP_NO_i)
!
!  TOLP + NO  -->  0.95_JPRB*NO2 + 0.95_JPRB*HO2 + 1.20_JPRB*GLY + 0.50_JPRB*DCB +
!                0.05_JPRB*ONIT + 0.65_JPRB*MGLY
   v_4(JP4_TOLP_NO_i) = 4.00D-12
   v_4(JP4_TOLP_NO_ii) =v_4(JP4_TOLP_NO_i)
   v_4(JP4_TOLP_NO_iii) =v_4(JP4_TOLP_NO_i)
!
!  XYLP + NO  -->  0.95_JPRB*NO2 + 0.95_JPRB*HO2 + 0.35_JPRB*GLY + 0.95_JPRB*DCB +
!                0.05_JPRB*ONIT + 0.60_JPRB*MGLY
   v_4(JP4_XYLP_NO_i) = 4.00D-12 
   v_4(JP4_XYLP_NO_ii) = v_4(JP4_XYLP_NO_i)
   v_4(JP4_XYLP_NO_iii) = v_4(JP4_XYLP_NO_i)
!
!  CSLP + NO  -->  GLY + MGLY + NO2 + HO2
   v_4(JP4_CSLP_NO_i)  = 4.00D-12 
   v_4(JP4_CSLP_NO_ii) = v_4(JP4_CSLP_NO_i)
!
!  ACO3 + NO  -->  MO2 + NO2
   v_4(JP4_ACO3_NO) = 2.00D-11 
!
!  TCO3 + NO  -->  NO2 + ACO3 + HCHO
   v_4(JP4_TCO3_NO_i) = 2.00D-11 
   v_4(JP4_TCO3_NO_ii) =v_4(JP4_TCO3_NO_i)
!
!  KETP + NO  -->  0.54_JPRB*MGLY + 0.46_JPRB*ALD + 0.23_JPRB*ACO3 + 0.77_JPRB*HO2 + 0.16_JPRB*XO2 + NO2
   v_4(JP4_KETP_NO_i) = 4.00D-12
   v_4(JP4_KETP_NO_ii) =v_4(JP4_KETP_NO_i)
   v_4(JP4_KETP_NO_iii) =v_4(JP4_KETP_NO_i)
!
!  OLNN + NO  -->  ONIT + NO2 + HO2
!
   v_4(JP4_OLNN_NO_i) = 4.00D-12 
   v_4(JP4_OLNN_NO_ii)=v_4(JP4_OLNN_NO_i)
!
!  OLND + NO  -->  0.287_JPRB*HCHO + 1.24_JPRB*ALD + 0.464_JPRB*KET + 2.0_JPRB*NO2
   v_4(JP4_OLND_NO_i) = 4.00D-12 
   v_4(JP4_OLND_NO_ii)=v_4(JP4_OLND_NO_i)
!
!  MO2 + HO2  -->  OP1
   v_4(JP4_MO2_HO2) = 3.80D-13 *exp(800.0_JPRB /PT)
!
!  ETHP + HO2  -->  OP2
   v_4(JP4_ETHP_HO2) = 7.50D-13 *exp(700.0_JPRB /PT)
!
!  HC3P + HO2  -->  OP2
   v_4(JP4_HC3P_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  HC5P + HO2  -->  OP2
   v_4(JP4_HC5P_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  HC8P + HO2  -->  OP2
   v_4(JP4_HC8P_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  ETEP + HO2  -->  OP2
   v_4(JP4_ETEP_HO2) = 1.90D-13 *exp(1300.0_JPRB /PT)
!
!  OLTP + HO2  -->  OP2
   v_4(JP4_OLTP_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  OLIP + HO2  -->  OP2
   v_4(JP4_OLIP_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  ISOP + HO2  -->  OP2
   v_4(JP4_ISOP_HO2) = 1.28D-13 *exp(1300.0_JPRB /PT)
!
!  APIP + HO2  -->  OP2
   v_4(JP4_APIP_HO2) = 1.50D-11
!
!  LIMP + HO2  -->  OP2
   v_4(JP4_LIMP_HO2) = 1.50D-11
!
!  TOLP + HO2  -->  OP2
   v_4(JP4_TOLP_HO2) = 3.75D-13 *exp(980.0_JPRB /PT)
!
!  XYLP + HO2  -->  OP2
   v_4(JP4_XYLP_HO2) = 3.75D-13 *exp(980.0_JPRB /PT)
!
!  CSLP + HO2  -->  OP2
   v_4(JP4_CSLP_HO2) = 3.75D-13 *exp(980.0_JPRB /PT)
!
!  ACO3 + HO2  -->  PAA
   v_4(JP4_ACO3_HO2a) = 1.15D-12 *exp(550.0_JPRB /PT)
!
!  ACO3 + HO2  -->  ORA2 + O3
   v_4(JP4_ACO3_HO2b) = 3.86D-16 *exp(2640.0_JPRB /PT)
!
!  TCO3 + HO2  -->  OP2
   v_4(JP4_TCO3_HO2a) = 1.15D-12 *exp(550.0_JPRB /PT)
!
!  TCO3 + HO2  -->  ORA2 + O3
   v_4(JP4_TCO3_HO2b) = 3.86D-16 *exp(2640.0_JPRB /PT)
!
!  KETP + HO2  -->  OP2
   v_4(JP4_KETP_HO2) = 1.15D-13 *exp(1300.0_JPRB /PT)
!
!  OLNN + HO2  -->  ONIT
   v_4(JP4_OLNN_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  OLND + HO2  -->  ONIT
   v_4(JP4_OLND_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  MO2 + MO2  -->  CH3O + CH3O + O2
   v_3(JP3_MO2_MO2a) = 0._JPRB;!0.35_JPRB *2.5D-13 *exp(190.0_JPRB /PT)
!
!  MO2 + MO2  -->  1.33_JPRB HCHO +0.66_JPRB HO2 !HCHO  + O2 + XX
   v_3(JP3_MO2_MO2b) = 9.10D-14*exp(416.0_JPRB/PT);!0.65_JPRB *2.5D-13 *exp(190.0_JPRB /PT)
!
!  ETHP + MO2  -->  0.75_JPRB*HCHO + HO2 + 0.75_JPRB*ALD
   v_4(JP4_ETHP_MO2_i) = 1.18D-13 *exp(158.0_JPRB /PT)
   v_4(JP4_ETHP_MO2_ii) =v_4(JP4_ETHP_MO2_i)
!
!  HC3P + MO2  -->  0.810_JPRB*HCHO + 0.992_JPRB*HO2 + 0.580_JPRB*ALD +
!                0.018_JPRB*KET + 0.007_JPRB*MO2 + 0.005_JPRB*MGLY + 0.085_JPRB*XO2 + 0.119_JPRB*GLY
   v_4(JP4_HC3P_MO2_i) = 9.46D-14 *exp(431.0_JPRB /PT)
   v_4(JP4_HC3P_MO2_ii) = v_4(JP4_HC3P_MO2_i)
   v_4(JP4_HC3P_MO2_iii) = v_4(JP4_HC3P_MO2_i)
   v_4(JP4_HC3P_MO2_iv) = v_4(JP4_HC3P_MO2_i)
!
!  HC5P + MO2  -->  0.829_JPRB*HCHO + 0.946_JPRB*HO2 + 0.523_JPRB*ALD +
!                0.240_JPRB*KET + 0.014_JPRB*ETHP + 0.245_JPRB*XO2 + 0.049_JPRB*MO2
    v_4(JP4_HC5P_MO2_i) = 1.00D-13 *exp(467.0_JPRB /PT)
    v_4(JP4_HC5P_MO2_ii) =v_4(JP4_HC5P_MO2_i)
    v_4(JP4_HC5P_MO2_iii) =v_4(JP4_HC5P_MO2_i)
    v_4(JP4_HC5P_MO2_iv) =v_4(JP4_HC5P_MO2_i)
!
!  HC8P + MO2  -->  0.753_JPRB*HCHO + 0.993_JPRB*HO2 + 0.411_JPRB*ALD +
!                0.419_JPRB*KET + 0.322_JPRB*XO2 + 0.013_JPRB*ETHP
   v_4(JP4_HC8P_MO2_i) = 4.34D-14 *exp(633.0_JPRB /PT)
   v_4(JP4_HC8P_MO2_ii) =v_4(JP4_HC8P_MO2_i)
   v_4(JP4_HC8P_MO2_iii) =v_4(JP4_HC8P_MO2_i)
!
!  ETEP + MO2  -->  1.55_JPRB*HCHO + HO2 + 0.35_JPRB*ALD
   v_4(JP4_ETEP_MO2_i) = 1.71D-13 *exp(708.0_JPRB /PT)
   v_4(JP4_ETEP_MO2_ii) =v_4(JP4_ETEP_MO2_i)
!
!  OLTP + MO2  -->  1.25_JPRB*HCHO + HO2 + 0.669_JPRB*ALD + 0.081_JPRB*KET
   v_4(JP4_OLTP_MO2_i) = 1.46D-13 *exp(708.0_JPRB /PT)
   v_4(JP4_OLTP_MO2_ii) =v_4(JP4_OLTP_MO2_i)
!
!  OLIP + MO2  -->  0.755_JPRB*HCHO + HO2 + 0.932_JPRB*ALD + 0.313_JPRB*KET
   v_4(JP4_OLIP_MO2_i) = 9.18D-14 *exp(708.0_JPRB /PT)
   v_4(JP4_OLIP_MO2_ii) =v_4(JP4_OLIP_MO2_i)
!
!  ISOP + MO2  -->  0.550_JPRB*MACR + 0.370_JPRB*OLT + HO2 + 0.080_JPRB*OLI + 1.09_JPRB*HCHO
   v_4(JP4_ISOP_MO2_i) = 1.36D-13 *exp(708.0_JPRB /PT)
   v_4(JP4_ISOP_MO2_ii) = v_4(JP4_ISOP_MO2_i)
   v_4(JP4_ISOP_MO2_iii) = v_4(JP4_ISOP_MO2_i)
!
!  APIP + MO2  -->  HO2 + HO2 + ALD + HCHO + KET
   v_4(JP4_APIP_MO2_i) = 3.56D-14 *exp(708.0_JPRB /PT)
   v_4(JP4_APIP_MO2_ii) = v_4(JP4_APIP_MO2_i)
!
!  LIMP + MO2  -->  2.00_JPRB*HO2 + 0.60_JPRB*MACR + 0.40_JPRB*OLI + 1.40_JPRB*HCHO
   v_4(JP4_LIMP_MO2_i) = 3.56D-14 *exp(708.0_JPRB /PT)
   v_4(JP4_LIMP_MO2_ii) =v_4(JP4_LIMP_MO2_i)
!
!  TOLP + MO2  -->  HCHO + HO2 + 0.65_JPRB*GLY + DCB + 0.35_JPRB*MGLY
   v_4(JP4_TOLP_MO2_i) = 3.56D-14 *exp(708.0_JPRB /PT)
   v_4(JP4_TOLP_MO2_ii) =v_4(JP4_TOLP_MO2_i)
   v_4(JP4_TOLP_MO2_iii) =v_4(JP4_TOLP_MO2_i)
!
!  XYLP + MO2  -->  HCHO + HO2 + 0.37_JPRB*GLY + DCB + 0.63_JPRB*MGLY
   v_4(JP4_XYLP_MO2_i) = 3.56D-14 *exp(708.0_JPRB /PT)
   v_4(JP4_XYLP_MO2_ii) =v_4(JP4_XYLP_MO2_i)
   v_4(JP4_XYLP_MO2_iii) =v_4(JP4_XYLP_MO2_i)
!
!  CSLP + MO2  -->  GLY + MGLY + HO2 + HO2 + HCHO
   v_4(JP4_CSLP_MO2_i) = 3.56D-14 *exp(708.0_JPRB /PT)
   v_4(JP4_CSLP_MO2_ii) = v_4(JP4_CSLP_MO2_i)
!
!  ACO3 + MO2  -->  HCHO + HO2 + MO2
   v_4(JP4_ACO3_MO2a_i) = 3.21D-11 *exp(-(440.0_JPRB /PT))
   v_4(JP4_ACO3_MO2a_ii) = v_4(JP4_ACO3_MO2a_i)
!
!  ACO3 + MO2  -->  HCHO + ORA2
   v_4(JP4_ACO3_MO2b) = 2.68D-16 *exp(2510.0_JPRB /PT)
!
!  TCO3 + MO2  -->  ACO3 + HCHO + HCHO + HO2
   v_4(JP4_TCO3_MO2a_i) = 3.21D-11 *exp(-(440.0_JPRB /PT))
   v_4(JP4_TCO3_MO2a_ii) = v_4(JP4_TCO3_MO2a_i)
!
!  TCO3 + MO2  -->  HCHO + ORA2
   v_4(JP4_TCO3_MO2b) = 2.68D-16 *exp(2510.0_JPRB /PT)
!
!  KETP + MO2  -->  0.40_JPRB*MGLY + 0.30_JPRB*ALD + 0.30_JPRB*HKET + 0.88_JPRB*HO2 +
!                0.08_JPRB*XO2 + 0.12_JPRB*ACO3 + 0.75_JPRB*HCHO
   v_4(JP4_KETP_MO2_i) = 6.91D-13 *exp(508.0_JPRB /PT)
   v_4(JP4_KETP_MO2_ii) =v_4(JP4_KETP_MO2_i)
   v_4(JP4_KETP_MO2_iii)=v_4(JP4_KETP_MO2_i)
   v_4(JP4_KETP_MO2_iv) =v_4(JP4_KETP_MO2_i)
!
!  OLNN + MO2  -->  0.75_JPRB*HCHO + HO2 + ONIT
   v_4(JP4_OLNN_MO2_i)  = 1.60D-13 *exp(708.0_JPRB /PT)
   v_4(JP4_OLNN_MO2_ii) = v_4(JP4_OLNN_MO2_i)
!
!  OLND + MO2  -->  0.960_JPRB*HCHO + 0.500_JPRB*HO2 + 0.640_JPRB*ALD +
!                0.149_JPRB*KET + 0.500_JPRB*NO2 + 0.500_JPRB*ONIT
   v_4(JP4_OLND_MO2_i) = 9.68D-14 *exp(708.0_JPRB /PT)
   v_4(JP4_OLND_MO2_ii) =v_4(JP4_OLND_MO2_i)
   v_4(JP4_OLND_MO2_iii) =v_4(JP4_OLND_MO2_i)
!
!  ETHP + ACO3  -->  ALD + 0.500_JPRB*HO2 + 0.5_JPRB*MO2 + 0.5_JPRB*ORA2
   v_4(JP4_ETHP_ACO3_i) = 1.03D-12 *exp(211.0_JPRB /PT)
   v_4(JP4_ETHP_ACO3_ii) = v_4(JP4_ETHP_ACO3_i)
!
!  HC3P + ACO3  -->  0.724_JPRB*ALD + 0.127_JPRB*KET + 0.488_JPRB*HO2 +
!                0.508_JPRB*MO2 + 0.499_JPRB*ORA2 + 0.091_JPRB*HCHO + 0.006_JPRB*ETHP + 0.071_JPRB*XO2 +
!                0.004_JPRB*MGLY + 0.100_JPRB*GLY
   v_4(JP4_HC3P_ACO3_i) = 6.90D-13 *exp(460.0_JPRB /PT)
   v_4(JP4_HC3P_ACO3_ii) =v_4(JP4_HC3P_ACO3_i)
   v_4(JP4_HC3P_ACO3_iii) =v_4(JP4_HC3P_ACO3_i)
   v_4(JP4_HC3P_ACO3_iv) =v_4(JP4_HC3P_ACO3_i)
   v_4(JP4_HC3P_ACO3_v) =v_4(JP4_HC3P_ACO3_i)
!
!  HC5P + ACO3  -->  0.677_JPRB*ALD + 0.330_JPRB*KET + 0.438_JPRB*HO2 +
!                0.554_JPRB*MO2 + 0.495_JPRB*ORA2 + 0.076_JPRB*HCHO + 0.018_JPRB*ETHP + 0.237_JPRB*XO2
   v_4(JP4_HC5P_ACO3_i) = 5.59D-13 *exp(522.0_JPRB /PT)
   v_4(JP4_HC5P_ACO3_ii) =v_4(JP4_HC5P_ACO3_i) 
   v_4(JP4_HC5P_ACO3_iii) =v_4(JP4_HC5P_ACO3_i) 
   v_4(JP4_HC5P_ACO3_iv) =v_4(JP4_HC5P_ACO3_i) 
!
!  HC8P + ACO3  -->  0.497_JPRB*ALD + 0.581_JPRB*KET + 0.489_JPRB*HO2 +
!                0.507_JPRB*MO2 + 0.495_JPRB*ORA2 + 0.015_JPRB*ETHP + 0.318_JPRB*XO2
   v_4(JP4_HC8P_ACO3_i) = 2.47D-13 *exp(683.0_JPRB /PT)
   v_4(JP4_HC8P_ACO3_ii) =v_4(JP4_HC8P_ACO3_i)
   v_4(JP4_HC8P_ACO3_iii) =v_4(JP4_HC8P_ACO3_i)
   v_4(JP4_HC8P_ACO3_iv) =v_4(JP4_HC8P_ACO3_i)
!
!  ETEP + ACO3  -->  0.8_JPRB*HCHO + 0.6_JPRB*ALD + 0.5_JPRB*HO2 + 0.5_JPRB*MO2 + 0.5_JPRB*ORA2
   v_4(JP4_ETEP_ACO3_i) = 9.48D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_ETEP_ACO3_ii) =v_4(JP4_ETEP_ACO3_i)
!
!  OLTP + ACO3  -->  0.859_JPRB*ALD + 0.501_JPRB*HCHO + 0.501_JPRB*HO2 +
!                0.501_JPRB*MO2 + 0.499_JPRB*ORA2 + 0.141_JPRB*KET
   v_4(JP4_OLTP_ACO3_i) = 8.11D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_OLTP_ACO3_ii) =v_4(JP4_OLTP_ACO3_i)
   v_4(JP4_OLTP_ACO3_iii) =v_4(JP4_OLTP_ACO3_i)
!
!  OLIP + ACO3  -->  0.941_JPRB*ALD + 0.510_JPRB*HO2 + 0.510_JPRB*MO2 + 0.569_JPRB*KET + 0.490_JPRB*ORA2
   v_4(JP4_OLIP_ACO3_i) = 5.09D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_OLIP_ACO3_ii) =v_4(JP4_OLIP_ACO3_i)
!
!  ISOP + ACO3  -->  0.771_JPRB*MACR + 0.229_JPRB*OLT + 0.506_JPRB*HO2 +
!                0.494_JPRB*ORA2 + 0.340_JPRB*HCHO + 0.506_JPRB*MO2
   v_4(JP4_ISOP_ACO3_i) = 7.60D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_ISOP_ACO3_ii) = v_4(JP4_ISOP_ACO3_i)
   v_4(JP4_ISOP_ACO3_iii) = v_4(JP4_ISOP_ACO3_i)
!
!  APIP + ACO3  -->  HO2 + ALD + MO2 + KET
   v_4(JP4_APIP_ACO3_i) = 7.40D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_APIP_ACO3_ii) =v_4(JP4_APIP_ACO3_i)
!
!  LIMP + ACO3  -->  HO2 + 0.60_JPRB*MACR + 0.40_JPRB*OLI + 0.40_JPRB*HCHO + MO2
   v_4(JP4_LIMP_ACO3_i) = 7.40D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_LIMP_ACO3_ii) =v_4(JP4_LIMP_ACO3_i)
   v_4(JP4_LIMP_ACO3_iii)=v_4(JP4_LIMP_ACO3_i)
!
!  TOLP + ACO3  -->  MO2 + HO2 + DCB + 0.65_JPRB*GLY + 0.35_JPRB*MGLY
   v_4(JP4_TOLP_ACO3_i) = 7.40D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_TOLP_ACO3_ii) =v_4(JP4_TOLP_ACO3_i)
   v_4(JP4_TOLP_ACO3_iii)=v_4(JP4_TOLP_ACO3_i)
!
!  XYLP + ACO3  -->  MO2 + HO2 + DCB + 0.37_JPRB*GLY + 0.63_JPRB*MGLY
   v_4(JP4_XYLP_ACO3_i) = 7.40D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_XYLP_ACO3_ii) =v_4(JP4_XYLP_ACO3_i)
   v_4(JP4_XYLP_ACO3_iii) =v_4(JP4_XYLP_ACO3_i)
!
!  CSLP + ACO3  -->  GLY + MGLY + HO2 + MO2
   v_4(JP4_CSLP_ACO3_i) = 7.40D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_CSLP_ACO3_ii) =v_4(JP4_CSLP_ACO3_i)
!
!  ACO3 + ACO3  -->  MO2 + MO2
   v_3(JP3_ACO3_ACO3) = 2.80D-12 *exp(530.0_JPRB /PT)
!
!  TCO3 + ACO3  -->  MO2 + ACO3 + HCHO
   v_4(JP4_TCO3_ACO3_i) = 2.80D-12 *exp(530.0_JPRB /PT)
   v_4(JP4_TCO3_ACO3_ii) =v_4(JP4_TCO3_ACO3_i)
!
!  KETP + ACO3  -->  0.54_JPRB*MGLY + 0.35_JPRB*ALD + 0.11_JPRB*KET +
!                0.12_JPRB*ACO3 + 0.38_JPRB*HO2 + 0.08_JPRB*XO2 + 0.50_JPRB*MO2 + 0.50_JPRB*ORA2
   v_4(JP4_KETP_ACO3_i) = 7.51D-13 *exp(565.0_JPRB /PT)
   v_4(JP4_KETP_ACO3_ii) =v_4(JP4_KETP_ACO3_i)
   v_4(JP4_KETP_ACO3_iii) =v_4(JP4_KETP_ACO3_i)
   v_4(JP4_KETP_ACO3_iv) =v_4(JP4_KETP_ACO3_i)
!
!  OLNN + ACO3  -->  ONIT + 0.50_JPRB*MO2 + 0.50_JPRB*ORA2 + 0.50_JPRB*HO2
   v_4(JP4_OLNN_ACO3_i) = 8.85D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_OLNN_ACO3_ii) =v_4(JP4_OLNN_ACO3_i)
!
!  OLND + ACO3  -->  0.207_JPRB*HCHO + 0.650_JPRB*ALD + 0.167_JPRB*KET +
!                0.516_JPRB*MO2 + 0.484_JPRB*ORA2 + 0.484_JPRB*ONIT + 0.516_JPRB*NO2
   v_4(JP4_OLND_ACO3_i) = 5.37D-13 *exp(765.0_JPRB /PT)
   v_4(JP4_OLND_ACO3_ii) =v_4(JP4_OLND_ACO3_i)
   v_4(JP4_OLND_ACO3_iii) =v_4(JP4_OLND_ACO3_i)
!
!  OLNN + OLNN  -->  ONIT + ONIT + HO2
   v_3(JP3_OLNN_OLNN) = 7.00D-14 *exp(1000.0_JPRB /PT)
!
!  OLNN + OLND  -->  0.202_JPRB*HCHO + 0.640_JPRB*ALD + 0.149_JPRB*KET +
!                0.500_JPRB*HO2 + 0.500_JPRB*NO2 + 1.50_JPRB*ONIT
   v_4(JP4_OLNN_OLND_i) = 4.25D-14 *exp(1000.0_JPRB /PT)
   v_4(JP4_OLNN_OLND_ii) =v_4(JP4_OLNN_OLND_i)
   v_4(JP4_OLNN_OLND_iii) =v_4(JP4_OLNN_OLND_i)
!
!  OLND + OLND  -->  0.504_JPRB*HCHO + 1.21_JPRB*ALD + 0.285_JPRB*KET + ONIT + NO2
   v_3(JP3_OLND_OLND_i) = 2.96D-14 *exp(1000.0_JPRB /PT)
   v_3(JP3_OLND_OLND_ii) =v_3(JP3_OLND_OLND_i)
   v_3(JP3_OLND_OLND_iii) =v_3(JP3_OLND_OLND_i)
!
!  MO2 + NO3  -->  HCHO + HO2 + NO2
   v_4(JP4_MO2_NO3_i) = 1.20D-12
   v_4(JP4_MO2_NO3_ii) =v_4(JP4_MO2_NO3_i)
!
!  ETHP + NO3  -->  ALD + HO2 + NO2
   v_4(JP4_ETHP_NO3_i) = 1.20D-12 
   v_4(JP4_ETHP_NO3_ii) =v_4(JP4_ETHP_NO3_i)
!
!  HC3P + NO3  -->  0.048_JPRB*HCHO + 0.243_JPRB*ALD + 0.670_JPRB*KET +
!                0.063_JPRB*GLY + 0.792_JPRB*HO2 + 0.155_JPRB*MO2 + 0.053_JPRB*ETHP + 0.051_JPRB*XO2
!                + NO2
   v_4(JP4_HC3P_NO3_i) = 1.20D-12
   v_4(JP4_HC3P_NO3_ii) =v_4(JP4_HC3P_NO3_i)
   v_4(JP4_HC3P_NO3_iii) =v_4(JP4_HC3P_NO3_i)
   v_4(JP4_HC3P_NO3_iv) =v_4(JP4_HC3P_NO3_i)
   v_4(JP4_HC3P_NO3_v) =v_4(JP4_HC3P_NO3_i)
!
!  HC5P + NO3  -->  0.021_JPRB*HCHO + 0.239_JPRB*ALD + 0.828_JPRB*KET +
!                0.699_JPRB*HO2 + 0.040_JPRB*MO2 + 0.262_JPRB*ETHP + 0.391_JPRB*XO2 + NO2
   v_4(JP4_HC5P_NO3_i) = 1.20D-12
   v_4(JP4_HC5P_NO3_ii) =v_4(JP4_HC5P_NO3_i)
   v_4(JP4_HC5P_NO3_iii) =v_4(JP4_HC5P_NO3_i)
   v_4(JP4_HC5P_NO3_iv) =v_4(JP4_HC5P_NO3_i)
!
!  HC8P + NO3  -->  0.187_JPRB*ALD + 0.880_JPRB*KET + 0.155_JPRB*ETHP + NO2 +
!                0.845_JPRB*HO2 + 0.587_JPRB*XO2
   v_4(JP4_HC8P_NO3_i) = 1.20D-12 
   v_4(JP4_HC8P_NO3_ii) =v_4(JP4_HC8P_NO3_i)
   v_4(JP4_HC8P_NO3_iii) =v_4(JP4_HC8P_NO3_i)
!
!  ETEP + NO3  -->  1.6_JPRB*HCHO + HO2 + NO2 + 0.2_JPRB*ALD
   v_4(JP4_ETEP_NO3_i) = 1.20D-12 
   v_4(JP4_ETEP_NO3_ii) =v_4(JP4_ETEP_NO3_i)
!
!  OLTP + NO3  -->  0.94_JPRB*ALD + HCHO + HO2 + NO2 + 0.06_JPRB*KET
   v_4(JP4_OLTP_NO3_i) = 1.20D-12
   v_4(JP4_OLTP_NO3_ii) =v_4(JP4_OLTP_NO3_i)
   v_4(JP4_OLTP_NO3_iii) =v_4(JP4_OLTP_NO3_i)
!
!  OLIP + NO3  -->  HO2 + 1.71_JPRB*ALD + 0.29_JPRB*KET + NO2
   v_4(JP4_OLIP_NO3_i) = 1.20D-12
   v_4(JP4_OLIP_NO3_ii) =v_4(JP4_OLIP_NO3_i)
!
!  ISOP + NO3  -->  0.600_JPRB*MACR + 0.400_JPRB*OLT + HO2 + NO2 + 0.686_JPRB*HCHO
   v_4(JP4_ISOP_NO3_i) = 1.20D-12 
   v_4(JP4_ISOP_NO3_ii) =v_4(JP4_ISOP_NO3_i)
   v_4(JP4_ISOP_NO3_iii) =v_4(JP4_ISOP_NO3_i)
!
!  APIP + NO3  -->  HO2 + ALD + NO2 + KET
   v_4(JP4_APIP_NO3_i) = 1.20D-12
   v_4(JP4_APIP_NO3_ii) =v_4(JP4_APIP_NO3_i)
!
!  LIMP + NO3  -->  HO2 + 0.60_JPRB*MACR + 0.40_JPRB*OLI + 0.40_JPRB*HCHO + NO2
   v_4(JP4_LIMP_NO3_i) = 1.20D-12 
   v_4(JP4_LIMP_NO3_ii) =v_4(JP4_LIMP_NO3_i)
   v_4(JP4_LIMP_NO3_iii) =v_4(JP4_LIMP_NO3_i)
!
!  TOLP + NO3  -->  NO2 + HO2 + 0.50_JPRB*DCB + 1.30_JPRB*GLY + 0.70_JPRB*MGLY
   v_4(JP4_TOLP_NO3_i) = 1.20D-12
   v_4(JP4_TOLP_NO3_ii) =v_4(JP4_TOLP_NO3_i)
   v_4(JP4_TOLP_NO3_iii) =v_4(JP4_TOLP_NO3_i)
!
!  XYLP + NO3  -->  NO2 + HO2 + DCB + 0.74_JPRB*GLY + 1.26_JPRB*MGLY
   v_4(JP4_XYLP_NO3_i) = 1.20D-12
   v_4(JP4_XYLP_NO3_ii) =v_4(JP4_XYLP_NO3_i)
   v_4(JP4_XYLP_NO3_iii) =v_4(JP4_XYLP_NO3_i)
!
!  CSLP + NO3  -->  GLY + MGLY + NO2 + HO2
   v_4(JP4_CSLP_NO3_i) = 1.20D-12
   v_4(JP4_CSLP_NO3_ii) =v_4(JP4_CSLP_NO3_i)
!
!  ACO3 + NO3  -->  MO2 + NO2
!
   v_4(JP4_ACO3_NO3) = 4.00D-12
!
!  TCO3 + NO3  -->  NO2 + ACO3 + HCHO
   v_4(JP4_TCO3_NO3_i) = 4.00D-12 
   v_4(JP4_TCO3_NO3_ii) =v_4(JP4_TCO3_NO3_i)
!
!  KETP + NO3  -->  0.54_JPRB*MGLY + 0.46_JPRB*ALD + 0.23_JPRB*ACO3 + 0.77_JPRB*HO2 + 0.16_JPRB*XO2 + NO2
   v_4(JP4_KETP_NO3_i) = 1.20D-12
   v_4(JP4_KETP_NO3_ii) =v_4(JP4_KETP_NO3_i)
   v_4(JP4_KETP_NO3_iii) =v_4(JP4_KETP_NO3_i)
!
!  OLNN + NO3  -->  ONIT + NO2 + HO2
   v_4(JP4_OLNN_NO3_i) = 1.20D-12 
   v_4(JP4_OLNN_NO3_ii) =v_4(JP4_OLNN_NO3_i)
!
!  OLND + NO3  -->  0.280_JPRB*HCHO + 1.24_JPRB*ALD + 0.469_JPRB*KET + 2.0_JPRB*NO2
   v_4(JP4_OLND_NO3_i) = 1.20D-12
   v_4(JP4_OLND_NO3_ii) =v_4(JP4_OLND_NO3_i)
!
!  XO2 + HO2  -->  OP2
   v_4(JP4_XO2_HO2) = 1.66D-13 *exp(1300.0_JPRB /PT)
!
!  XO2 + MO2  -->  HCHO + HO2
   v_4(JP4_XO2_MO2) = 5.99D-15 *exp(1510.0_JPRB /PT)
!
!  XO2 + ACO3  -->  MO2
   v_4(JP4_XO2_ACO3) = 3.40D-14 *exp(1560.0_JPRB /PT)
!
!  XO2 + XO2  -->
   v_3(JP3_XO2_XO2) = 7.13D-17 *exp(2950.0_JPRB /PT)
!
!  XO2 + NO  -->  NO2
   v_4(JP4_XO2_NO) = 4.00D-12
!
!  XO2 + NO3  -->  NO2
   v_4(JP4_XO2_NO3) = 1.20D-12
!
!  DMS + NO3  -->  SO2 + NO2
   v_4(JP4_DMS_NO3) = 5.4D-13
!
!  DMS + O3P  -->  SO2
   v_4(JP4_DMS_O3P) = 1.3D-11 *exp(400.0_JPRB /PT)
!
!  DMS + OH  -->  0.8_JPRB*SO2 + 0.2_JPRB*MSA
!
   v_4(JP4_DMS_OH) = (PT*exp(-234.0_JPRB /PT)+8.4D-10 *exp(7230.0_JPRB/PT)+2.68D-10*exp(7810.0_JPRB/PT))/(1.04D11*PT+88.1_JPRB*exp(7460.0_JPRB/PT))
!
!  H + O2  -->  HO2
!
   ZK0   = 4.40D-32 
   ZE0   = 0.0_JPRB 
   ZN0   = 1.3_JPRB 
   ZKINF = 4.70D-11 
   ZEINF = 0.0_JPRB 
   ZMINF = 0.2_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_4(JP4_H_O2) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  O3 + H  -->  OH + O2
!
   v_4(JP4_O3_H) = 1.4D-10 *exp(-470.0_JPRB /PT)
!
!  O1D + H2  -->  OH + H
!
   v_phot(JPO_O1D_H2) = 1.1D-10*5.D-07*PHNM 
!
!  O3P + OH  -->  O2 + H
!
   v_4(JP4_O3P_OH) = 2.2D-11 *exp(120.0_JPRB /PT)
!
!  O3P + HO2  -->  OH + O2
!
   v_4(JP4_O3P_HO2) = 3.0D-11 *exp(200.0_JPRB /PT)
!
!  H + HO2  -->  OH + OH
!
   v_4(JP4_H_HO2a) = 7.2D-11
!
!  H + HO2  -->  H2 + O2
!
   v_4(JP4_H_HO2b) = 6.9D-12 
!
!  H + HO2  -->  H2O + O3P
!
   v_4(JP4_H_HO2c) = 1.6D-12
!
!  H2 + O3P  -->  OH + H
!
   v_phot(JPO_H2_O3P) = 0._JPRB;!8.8D-12 *exp(-4200.0_JPRB /PT)*5.D-07*PHNM
!
!  OH + OH  -->  H2O + O3P
!
   v_3(JP3_OH_OHa) = 1.8D-12
!
!   OH + OH   -->   H2O2

   ZK0   = 6.90D-31 
   ZE0   = 0.0_JPRB 
   ZN0   = 1.0_JPRB 
   ZKINF = 2.60D-11 
   ZEINF = 0.0_JPRB 
   ZMINF = 0.0_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_3(JP3_OH_OHb) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  N + NO  -->  N2 + O3P
!
   v_4(JP4_N_NO) = 2.1D-11 *exp(100.0_JPRB /PT)
!
!  N + O2  -->  NO + O3P
!
   v_4(JP4_N_O2) = 1.5D-11 *exp(-3600.0_JPRB /PT)
!
!  O1D + N2O  -->  N2 + O2
!
   v_4(JP4_O1D_N2Oa) = 4.7D-11*exp( 20._JPRB/PT)
!
!  O1D + N2O  -->  NO + NO
!
   v_4(JP4_O1D_N2Ob) = 6.7D-11*exp( 20._JPRB/PT)
!
!  O1D + CH4  -->  OH + CH3
!
   v_4(JP4_O1D_CH4a) = 0.75_JPRB *1.5D-10
!
!  O1D + CH4  -->  CH3O + H
!
   v_4(JP4_O1D_CH4b) = 0.20_JPRB *1.5D-10 
!
!  O1D + CH4  -->  HCHO + H2
!
   v_4(JP4_O1D_CH4c) = 0.05_JPRB *1.5D-10
!
!  CH3 + O3P  -->  HCHO + H
!
   v_4(JP4_CH3_O3P) = 1.1D-10 
!
!  CH3 + O2  -->  MO2
!
   ZK0   = 4.0D-31
   ZE0   = 0.0_JPRB 
   ZN0   = 3.6_JPRB 
   ZKINF = 1.20D-12 
   ZEINF = 0.0_JPRB 
   ZMINF = -1.1_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_4(JP4_CH3_O2) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  HCHO + O3P  -->  HO2 + CO + OH
!
   v_4(JP4_HCHO_O3P_i) = 3.4D-11 *exp(-1600.0_JPRB /PT)
   v_4(JP4_HCHO_O3P_ii) =v_4(JP4_HCHO_O3P_i)
!
!  HCHO + Cl  -->  HO2 + CO + HCl
!
   v_4(JP4_HCHO_Cl_i) = 8.1D-11 *exp(-30.0_JPRB /PT)
   v_4(JP4_HCHO_Cl_ii) =v_4(JP4_HCHO_Cl_i)
!
!  CH3O + O2  -->  HCHO + HO2
!
   v_4(JP4_CH3O_O2) = 3.9D-14 *exp(-900.0_JPRB /PT)
!
!  MO2 + ClO  -->  CH3O + Cl + O2
!
   v_4(JP4_MO2_ClO) = 3.3D-12 *exp(-115.0_JPRB /PT)
!
!  HCHO + Br  -->  HO2 + CO + HBr
!
   v_4(JP4_HCHO_Br_i) = 1.7D-11 *exp(-800.0_JPRB /PT)
   v_4(JP4_HCHO_Br_ii) =v_4(JP4_HCHO_Br_i)
!
!  Cl + O3  -->  ClO + O2
!
   v_4(JP4_Cl_O3) = 2.3D-11 *exp(-200.0_JPRB /PT)
!
!  ClO + O3P  -->  Cl + O2
!
   v_4(JP4_ClO_O3P) = 2.8D-11*exp( 85._JPRB/PT)
!
!  ClO + NO  -->  NO2 + Cl
!
   v_4(JP4_ClO_NO) = 6.4D-12 *exp(290.0_JPRB /PT)
!
!  Cl + CH4  -->  HCl + CH3
!
   v_4(JP4_Cl_CH4) =  7.3D-12*exp(-1280._JPRB/PT)
!
!  Cl + H2  -->  HCl + H
!
   v_phot(JPO_Cl_H2) = 3.05D-11*exp(-2270._JPRB/PT)*5.D-07*PHNM
!
!  Cl + HO2  -->  HCl + O2
!
   v_4(JP4_Cl_HO2a) = 1.8D-11 *exp(170.0_JPRB /PT)
!
!  Cl + HO2  -->  OH + ClO
!
   v_4(JP4_Cl_HO2b) = 4.1D-11 *exp(-450.0_JPRB /PT)
!
!  ClO + OH  -->  Cl + HO2
!
   v_4(JP4_ClO_OHa) = 7.4D-12*exp( 270._JPRB/PT)
!
!  ClO + OH  -->  HCl + O2
!
   v_4(JP4_ClO_OHb) = 6.0D-13*exp( 230._JPRB/PT)
!
!  OH + HCl  -->  H2O + Cl
!
   v_4(JP4_OH_HCl) = 2.6D-12 *exp(-350.0_JPRB /PT)
!
!  ClO + NO2  -->  ClONO2
!
   ZK0   = 1.80D-31 
   ZE0   = 0.0_JPRB 
   ZN0   = 3.4_JPRB 
   ZKINF = 1.50D-11 
   ZEINF = 0.0_JPRB 
   ZMINF = 1.9_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_4(JP4_ClO_NO2) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  O3P + ClONO2  -->  ClOx + NOx + XX
!
   v_4(JP4_O3P_ClONO2) = 2.9D-12 *exp(-800.0_JPRB /PT)
!
!  ClO + HO2  -->  HOCl + O2
!
   v_4(JP4_ClO_HO2) = 2.7D-12*exp( 220._JPRB/PT)
!
!  OH + HOCl  -->  H2O + ClO
!
   v_4(JP4_OH_HOCl) = 3.0D-12 *exp(-500.0_JPRB /PT)
!
!  O3P + HOCl  -->  OH + ClO
!
   v_4(JP4_O3P_HOCl) = 1.7D-13
!
!  Cl + NO2  -->  ClNO2
!
   ZK0   = 1.80D-31 
   ZE0   = 0.0_JPRB 
   ZN0   = 2.0_JPRB 
   ZKINF = 1.00D-10 
   ZEINF = 0.0_JPRB 
   ZMINF = 1.0_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_4(JP4_Cl_NO2) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  Cl + HOCl  -->  OH + Cl2
!
   v_4(JP4_Cl_HOCl) = 2.5D-12 *exp(-130.0_JPRB /PT)
!
!  ClO + ClO  -->  Cl2O2
!
   ZK0   = 1.60D-32 
   ZE0   = 0.0_JPRB 
   ZN0   = 4.5_JPRB 
   ZKINF = 2.0D-12 
   ZEINF = 0.0_JPRB 
   ZMINF = 2.4_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_3(JP3_ClO_ClOa) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  Cl2O2  -->  ClO + ClO
!
   ZK0   = 1.60D-32
   ZN0   = 4.5_JPRB 
   ZKINF = 2.00D-12 
   ZMINF = 2.4_JPRB 
   ZAEQ  = 9.30D-28 
   ZBEQ  = 8835.0_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(0.6_JPRB))
   v_phot(JPO_Cl2O2) = (1.0_JPRB /(ZAEQ))*exp(-ZBEQ/PT)*(ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  ClO + ClO  -->  Cl2 + O2
!
   v_3(JP3_ClO_ClOb) = 1.0D-12 *exp(-1590.0_JPRB /PT)
!
!  ClO + ClO  -->  OClO + O2
!
   v_3(JP3_ClO_ClOc) = 3.0D-11*exp(-2450._JPRB/PT) + 3.5D-13*exp(-1370._JPRB/PT)
!
!  O1D + CFC11  -->  ClOx + ClOx + ClOx + XX
!
   v_4(JP4_O1D_CFC11) = 2.3D-10
!
!  O1D + CFC12  -->  ClOx + ClOx + XX
!
   v_4(JP4_O1D_CFC12) = 1.4D-10
!
!  O1D + CFC113  -->  ClOx + ClOx + ClOx + XX
!
   v_4(JP4_O1D_CFC113) = 2.0D-10 
!
!  O1D + CCl4  -->  ClOx + ClOx + ClOx + ClOx + XX
!
   v_4(JP4_O1D_CCl4) = 3.3D-10
!
!  OH + CH3CCl3  -->  ClOx + ClOx + ClOx + H2O + XX
!
   v_4(JP4_OH_CH3CCl3) = 1.64D-12*exp(-1520._JPRB/PT)
!
!  OH + CH3Cl  -->  ClOx + H2O + XX
!
   v_4(JP4_OH_CH3Cl) = 2.4D-12*exp(-1250._JPRB/PT)
!
!  O1D + HCFC22  -->  ClOx + XX
!
   v_4(JP4_O1D_HCFC22) = 1.0D-10
!
!  OH + HCFC22  -->  ClOx + H2O + XX
!
   v_4(JP4_OH_HCFC22) =  1.05D-12*exp(-1600._JPRB/PT)
!
!  Br + O3  -->  BrO + O2
!
   v_4(JP4_Br_O3) = 1.7D-11 *exp(-800.0_JPRB /PT)
!
!  BrO + O3P  -->  Br + O2
!
   v_4(JP4_BrO_O3P) = 1.9D-11 *exp(230.0_JPRB /PT)
!
!  BrO + NO  -->  NO2 + Br
!
   v_4(JP4_BrO_NO) = 8.8D-12 *exp(260.0_JPRB /PT)
!
!  BrO + ClO  -->  OClO + Br
!
   v_4(JP4_BrO_ClOa) = 9.5D-13*exp( 550._JPRB/PT)
!
!  BrO + ClO  -->  Br + Cl + O2
!
   v_4(JP4_BrO_ClOb) = 2.9D-12 *exp(260.0_JPRB /PT)
!
!  BrO + ClO  -->  BrCl + O2

   v_4(JP4_BrO_ClOc) = 4.1D-13*exp( 290._JPRB/PT)
!
!  BrO + BrO  -->  Br + Br + O2
!
   v_3(JP3_BrO_BrO) = 1.5D-12 *exp(230.0_JPRB /PT)
!
!  Br + HO2  -->  HBr + O2
!
   v_4(JP4_Br_HO2) = 4.8D-12*exp(-310._JPRB/PT)
!
!  O1D + HBr  -->  OH + Br
!
   v_4(JP4_O1D_HBr) = 1.5D-10
!
!  BrO + OH  -->  Br + HO2
!
   v_4(JP4_BrO_OH) = 1.7D-11*exp( 250._JPRB/PT)
!
!  OH + HBr  -->  H2O + Br
!
   v_4(JP4_OH_HBr) = 5.5D-12*exp( 200._JPRB/PT)
!
!  BrO + NO2  -->  BrONO2
!
   ZK0   = 5.20D-31
   ZE0   = 0.0_JPRB 
   ZN0   = 3.2_JPRB 
   ZKINF = 6.90D-12 
   ZEINF = 0.0_JPRB 
   ZMINF = 2.9_JPRB 
   ZF    = 0.6_JPRB 
   ZK0M  = PHNM*ZK0*exp((-ZN0)*log(PT/300._JPRB))*exp(-ZE0/PT)
   Z2KINF= ZKINF*exp((-ZMINF)*log(PT/300._JPRB))*exp(-ZEINF/PT)
   ZFACT = exp((1._JPRB/(1._JPRB+(log10(ZK0M/Z2KINF))*(log10(ZK0M/Z2KINF))))*log(ZF))
   v_4(JP4_BrO_NO2) = (ZK0M/(1.0_JPRB +ZK0M/Z2KINF))*ZFACT
!
!  BrO + HO2  -->  HOBr + O2
!
   v_4(JP4_BrO_HO2) = 4.5D-12*exp( 460._JPRB/PT)
!
!  HOBr + O3P  -->  OH + BrO
!
   v_4(JP4_HOBr_O3P) = 1.2D-10 *exp(-430.0_JPRB /PT)
!
!  O1D + CH3Br  -->  BrOx + XX
!
   v_4(JP4_O1D_CH3Br) = 1.8D-10
!
!  OH + CH3Br  -->  CH2Br + H2O
!
   v_4(JP4_OH_CH3Br) = 2.35D-12*exp(-1300._JPRB/PT)
!
!  O1D + H1211  -->  BrOx + XX
!
   v_4(JP4_O1D_H1211) = 1.5D-10
!
!  O1D + H1301  -->  BrOx + XX
   v_4(JP4_O1D_H1301) = 1.0D-10
!
!  O3P + O3P  -->  O2
!
   v_3(JP3_O3P_O3P) = 0._JPRB;!4.23D-28 *PHNM/(PT*PT)
!
!  ClONO2 + H2O  -->  HOCl + HNO3	cf heterogeneous chemistry

!  ClONO2 + HCl  -->  Cl2 + HNO3	cf heterogeneous chemistry

!  N2O5 + H2O  -->  HNO3 + HNO3		cf heterogeneous chemistry

!  N2O5 + HCl  -->  ClNO2 + HNO3	cf heterogeneous chemistry

!  HOCl + HCl  -->  Cl2 + H2O		cf heterogeneous chemistry

!  BrONO2 + H2O  -->  HOBr + HNO3	cf heterogeneous chemistry

!  HOBr + HCl  -->  BrCl + H2O		cf heterogeneous chemistry

!  HOBr + HBr  -->  BrOx + BrOx + H2O	cf heterogeneous chemistry

!  HOCl + HBr  -->  BrCl + H2O		cf heterogeneous chemistry

! Ajout d'une nouvelle reaction :
! HO2 + NO --> HNO3 
! Processus direct de formation de HNO3, concurrence
! la reaction 
! HO2 + NO + NO2 + OH (70 ici)
! BETA est pour l'instant calculee selon (Gottschaldt 2009, Proceedings
! de TAC-2) 
!
   BETA  = 0.01_JPRB*( 530.0_JPRB/PT+PHNM*PT*1.38D-17*4.8D-6 -1.73_JPRB)
!   
! La constante de la reaction 70 est ponderee
! en k1 = k0 / (1 + BETA)
!
   v_4(JP4_HO2_NOa)  = v_4(JP4_HO2_NOa) / (1.0_JPRB  + BETA)
!   
! La constante de la nouvelle reaction est
! k2 = k0 * BETA ( 1 + BETA) soit k2 = BETA k1 
! On a bien k2 + k1 = k0 
!
   v_4(JP4_HO2_NOb) = BETA * v_4(JP4_HO2_NOa)  
!

END SUBROUTINE reaction_rates
